/*
 * QEMU model of the PMC GIC Proxy.
 *
 * Copyright (c) 2017 Xilinx Inc.
 *
 * Partially autogenerated by xregqemu.py 2017-03-28.
 * Written by Edgar E. Iglesias.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

#include "qemu/osdep.h"
#include "hw/sysbus.h"
#include "hw/register-dep.h"
#include "qemu/bitops.h"
#include "qemu/log.h"

#ifndef XILINX_PMC_GIC_PROXY_ERR_DEBUG
#define XILINX_PMC_GIC_PROXY_ERR_DEBUG 0
#endif

#define TYPE_XILINX_PMC_GIC_PROXY "xlnx.pmc-gic-proxy"

#define XILINX_PMC_GIC_PROXY(obj) \
     OBJECT_CHECK(PMCGICProxy, (obj), TYPE_XILINX_PMC_GIC_PROXY)

DEP_REG32(GICP0_IRQ_STATUS, 0x0)
    DEP_FIELD(GICP0_IRQ_STATUS, SRC31, 1, 31)
    DEP_FIELD(GICP0_IRQ_STATUS, SRC30, 1, 30)
    DEP_FIELD(GICP0_IRQ_STATUS, SRC29, 1, 29)
    DEP_FIELD(GICP0_IRQ_STATUS, SRC28, 1, 28)
    DEP_FIELD(GICP0_IRQ_STATUS, SRC27, 1, 27)
    DEP_FIELD(GICP0_IRQ_STATUS, SRC26, 1, 26)
    DEP_FIELD(GICP0_IRQ_STATUS, SRC25, 1, 25)
    DEP_FIELD(GICP0_IRQ_STATUS, SRC24, 1, 24)
    DEP_FIELD(GICP0_IRQ_STATUS, SRC23, 1, 23)
    DEP_FIELD(GICP0_IRQ_STATUS, SRC22, 1, 22)
    DEP_FIELD(GICP0_IRQ_STATUS, SRC21, 1, 21)
    DEP_FIELD(GICP0_IRQ_STATUS, SRC20, 1, 20)
    DEP_FIELD(GICP0_IRQ_STATUS, SRC19, 1, 19)
    DEP_FIELD(GICP0_IRQ_STATUS, SRC18, 1, 18)
    DEP_FIELD(GICP0_IRQ_STATUS, SRC17, 1, 17)
    DEP_FIELD(GICP0_IRQ_STATUS, SRC16, 1, 16)
    DEP_FIELD(GICP0_IRQ_STATUS, SRC15, 1, 15)
    DEP_FIELD(GICP0_IRQ_STATUS, SRC14, 1, 14)
    DEP_FIELD(GICP0_IRQ_STATUS, SRC13, 1, 13)
    DEP_FIELD(GICP0_IRQ_STATUS, SRC12, 1, 12)
    DEP_FIELD(GICP0_IRQ_STATUS, SRC11, 1, 11)
    DEP_FIELD(GICP0_IRQ_STATUS, SRC10, 1, 10)
    DEP_FIELD(GICP0_IRQ_STATUS, SRC9, 1, 9)
    DEP_FIELD(GICP0_IRQ_STATUS, SRC8, 1, 8)
    DEP_FIELD(GICP0_IRQ_STATUS, SRC7, 1, 7)
    DEP_FIELD(GICP0_IRQ_STATUS, SRC6, 1, 6)
    DEP_FIELD(GICP0_IRQ_STATUS, SRC5, 1, 5)
    DEP_FIELD(GICP0_IRQ_STATUS, SRC4, 1, 4)
    DEP_FIELD(GICP0_IRQ_STATUS, SRC3, 1, 3)
    DEP_FIELD(GICP0_IRQ_STATUS, SRC2, 1, 2)
    DEP_FIELD(GICP0_IRQ_STATUS, SRC1, 1, 1)
    DEP_FIELD(GICP0_IRQ_STATUS, SRC0, 1, 0)
DEP_REG32(GICP0_IRQ_MASK, 0x4)
    DEP_FIELD(GICP0_IRQ_MASK, SRC31, 1, 31)
    DEP_FIELD(GICP0_IRQ_MASK, SRC30, 1, 30)
    DEP_FIELD(GICP0_IRQ_MASK, SRC29, 1, 29)
    DEP_FIELD(GICP0_IRQ_MASK, SRC28, 1, 28)
    DEP_FIELD(GICP0_IRQ_MASK, SRC27, 1, 27)
    DEP_FIELD(GICP0_IRQ_MASK, SRC26, 1, 26)
    DEP_FIELD(GICP0_IRQ_MASK, SRC25, 1, 25)
    DEP_FIELD(GICP0_IRQ_MASK, SRC24, 1, 24)
    DEP_FIELD(GICP0_IRQ_MASK, SRC23, 1, 23)
    DEP_FIELD(GICP0_IRQ_MASK, SRC22, 1, 22)
    DEP_FIELD(GICP0_IRQ_MASK, SRC21, 1, 21)
    DEP_FIELD(GICP0_IRQ_MASK, SRC20, 1, 20)
    DEP_FIELD(GICP0_IRQ_MASK, SRC19, 1, 19)
    DEP_FIELD(GICP0_IRQ_MASK, SRC18, 1, 18)
    DEP_FIELD(GICP0_IRQ_MASK, SRC17, 1, 17)
    DEP_FIELD(GICP0_IRQ_MASK, SRC16, 1, 16)
    DEP_FIELD(GICP0_IRQ_MASK, SRC15, 1, 15)
    DEP_FIELD(GICP0_IRQ_MASK, SRC14, 1, 14)
    DEP_FIELD(GICP0_IRQ_MASK, SRC13, 1, 13)
    DEP_FIELD(GICP0_IRQ_MASK, SRC12, 1, 12)
    DEP_FIELD(GICP0_IRQ_MASK, SRC11, 1, 11)
    DEP_FIELD(GICP0_IRQ_MASK, SRC10, 1, 10)
    DEP_FIELD(GICP0_IRQ_MASK, SRC9, 1, 9)
    DEP_FIELD(GICP0_IRQ_MASK, SRC8, 1, 8)
    DEP_FIELD(GICP0_IRQ_MASK, SRC7, 1, 7)
    DEP_FIELD(GICP0_IRQ_MASK, SRC6, 1, 6)
    DEP_FIELD(GICP0_IRQ_MASK, SRC5, 1, 5)
    DEP_FIELD(GICP0_IRQ_MASK, SRC4, 1, 4)
    DEP_FIELD(GICP0_IRQ_MASK, SRC3, 1, 3)
    DEP_FIELD(GICP0_IRQ_MASK, SRC2, 1, 2)
    DEP_FIELD(GICP0_IRQ_MASK, SRC1, 1, 1)
    DEP_FIELD(GICP0_IRQ_MASK, SRC0, 1, 0)
DEP_REG32(GICP0_IRQ_ENABLE, 0x8)
    DEP_FIELD(GICP0_IRQ_ENABLE, SRC31, 1, 31)
    DEP_FIELD(GICP0_IRQ_ENABLE, SRC30, 1, 30)
    DEP_FIELD(GICP0_IRQ_ENABLE, SRC29, 1, 29)
    DEP_FIELD(GICP0_IRQ_ENABLE, SRC28, 1, 28)
    DEP_FIELD(GICP0_IRQ_ENABLE, SRC27, 1, 27)
    DEP_FIELD(GICP0_IRQ_ENABLE, SRC26, 1, 26)
    DEP_FIELD(GICP0_IRQ_ENABLE, SRC25, 1, 25)
    DEP_FIELD(GICP0_IRQ_ENABLE, SRC24, 1, 24)
    DEP_FIELD(GICP0_IRQ_ENABLE, SRC23, 1, 23)
    DEP_FIELD(GICP0_IRQ_ENABLE, SRC22, 1, 22)
    DEP_FIELD(GICP0_IRQ_ENABLE, SRC21, 1, 21)
    DEP_FIELD(GICP0_IRQ_ENABLE, SRC20, 1, 20)
    DEP_FIELD(GICP0_IRQ_ENABLE, SRC19, 1, 19)
    DEP_FIELD(GICP0_IRQ_ENABLE, SRC18, 1, 18)
    DEP_FIELD(GICP0_IRQ_ENABLE, SRC17, 1, 17)
    DEP_FIELD(GICP0_IRQ_ENABLE, SRC16, 1, 16)
    DEP_FIELD(GICP0_IRQ_ENABLE, SRC15, 1, 15)
    DEP_FIELD(GICP0_IRQ_ENABLE, SRC14, 1, 14)
    DEP_FIELD(GICP0_IRQ_ENABLE, SRC13, 1, 13)
    DEP_FIELD(GICP0_IRQ_ENABLE, SRC12, 1, 12)
    DEP_FIELD(GICP0_IRQ_ENABLE, SRC11, 1, 11)
    DEP_FIELD(GICP0_IRQ_ENABLE, SRC10, 1, 10)
    DEP_FIELD(GICP0_IRQ_ENABLE, SRC9, 1, 9)
    DEP_FIELD(GICP0_IRQ_ENABLE, SRC8, 1, 8)
    DEP_FIELD(GICP0_IRQ_ENABLE, SRC7, 1, 7)
    DEP_FIELD(GICP0_IRQ_ENABLE, SRC6, 1, 6)
    DEP_FIELD(GICP0_IRQ_ENABLE, SRC5, 1, 5)
    DEP_FIELD(GICP0_IRQ_ENABLE, SRC4, 1, 4)
    DEP_FIELD(GICP0_IRQ_ENABLE, SRC3, 1, 3)
    DEP_FIELD(GICP0_IRQ_ENABLE, SRC2, 1, 2)
    DEP_FIELD(GICP0_IRQ_ENABLE, SRC1, 1, 1)
    DEP_FIELD(GICP0_IRQ_ENABLE, SRC0, 1, 0)
DEP_REG32(GICP0_IRQ_DISABLE, 0xc)
    DEP_FIELD(GICP0_IRQ_DISABLE, SRC31, 1, 31)
    DEP_FIELD(GICP0_IRQ_DISABLE, SRC30, 1, 30)
    DEP_FIELD(GICP0_IRQ_DISABLE, SRC29, 1, 29)
    DEP_FIELD(GICP0_IRQ_DISABLE, SRC28, 1, 28)
    DEP_FIELD(GICP0_IRQ_DISABLE, SRC27, 1, 27)
    DEP_FIELD(GICP0_IRQ_DISABLE, SRC26, 1, 26)
    DEP_FIELD(GICP0_IRQ_DISABLE, SRC25, 1, 25)
    DEP_FIELD(GICP0_IRQ_DISABLE, SRC24, 1, 24)
    DEP_FIELD(GICP0_IRQ_DISABLE, SRC23, 1, 23)
    DEP_FIELD(GICP0_IRQ_DISABLE, SRC22, 1, 22)
    DEP_FIELD(GICP0_IRQ_DISABLE, SRC21, 1, 21)
    DEP_FIELD(GICP0_IRQ_DISABLE, SRC20, 1, 20)
    DEP_FIELD(GICP0_IRQ_DISABLE, SRC19, 1, 19)
    DEP_FIELD(GICP0_IRQ_DISABLE, SRC18, 1, 18)
    DEP_FIELD(GICP0_IRQ_DISABLE, SRC17, 1, 17)
    DEP_FIELD(GICP0_IRQ_DISABLE, SRC16, 1, 16)
    DEP_FIELD(GICP0_IRQ_DISABLE, SRC15, 1, 15)
    DEP_FIELD(GICP0_IRQ_DISABLE, SRC14, 1, 14)
    DEP_FIELD(GICP0_IRQ_DISABLE, SRC13, 1, 13)
    DEP_FIELD(GICP0_IRQ_DISABLE, SRC12, 1, 12)
    DEP_FIELD(GICP0_IRQ_DISABLE, SRC11, 1, 11)
    DEP_FIELD(GICP0_IRQ_DISABLE, SRC10, 1, 10)
    DEP_FIELD(GICP0_IRQ_DISABLE, SRC9, 1, 9)
    DEP_FIELD(GICP0_IRQ_DISABLE, SRC8, 1, 8)
    DEP_FIELD(GICP0_IRQ_DISABLE, SRC7, 1, 7)
    DEP_FIELD(GICP0_IRQ_DISABLE, SRC6, 1, 6)
    DEP_FIELD(GICP0_IRQ_DISABLE, SRC5, 1, 5)
    DEP_FIELD(GICP0_IRQ_DISABLE, SRC4, 1, 4)
    DEP_FIELD(GICP0_IRQ_DISABLE, SRC3, 1, 3)
    DEP_FIELD(GICP0_IRQ_DISABLE, SRC2, 1, 2)
    DEP_FIELD(GICP0_IRQ_DISABLE, SRC1, 1, 1)
    DEP_FIELD(GICP0_IRQ_DISABLE, SRC0, 1, 0)
DEP_REG32(GICP0_IRQ_TRIGGER, 0x10)
    DEP_FIELD(GICP0_IRQ_TRIGGER, SRC31, 1, 31)
    DEP_FIELD(GICP0_IRQ_TRIGGER, SRC30, 1, 30)
    DEP_FIELD(GICP0_IRQ_TRIGGER, SRC29, 1, 29)
    DEP_FIELD(GICP0_IRQ_TRIGGER, SRC28, 1, 28)
    DEP_FIELD(GICP0_IRQ_TRIGGER, SRC27, 1, 27)
    DEP_FIELD(GICP0_IRQ_TRIGGER, SRC26, 1, 26)
    DEP_FIELD(GICP0_IRQ_TRIGGER, SRC25, 1, 25)
    DEP_FIELD(GICP0_IRQ_TRIGGER, SRC24, 1, 24)
    DEP_FIELD(GICP0_IRQ_TRIGGER, SRC23, 1, 23)
    DEP_FIELD(GICP0_IRQ_TRIGGER, SRC22, 1, 22)
    DEP_FIELD(GICP0_IRQ_TRIGGER, SRC21, 1, 21)
    DEP_FIELD(GICP0_IRQ_TRIGGER, SRC20, 1, 20)
    DEP_FIELD(GICP0_IRQ_TRIGGER, SRC19, 1, 19)
    DEP_FIELD(GICP0_IRQ_TRIGGER, SRC18, 1, 18)
    DEP_FIELD(GICP0_IRQ_TRIGGER, SRC17, 1, 17)
    DEP_FIELD(GICP0_IRQ_TRIGGER, SRC16, 1, 16)
    DEP_FIELD(GICP0_IRQ_TRIGGER, SRC15, 1, 15)
    DEP_FIELD(GICP0_IRQ_TRIGGER, SRC14, 1, 14)
    DEP_FIELD(GICP0_IRQ_TRIGGER, SRC13, 1, 13)
    DEP_FIELD(GICP0_IRQ_TRIGGER, SRC12, 1, 12)
    DEP_FIELD(GICP0_IRQ_TRIGGER, SRC11, 1, 11)
    DEP_FIELD(GICP0_IRQ_TRIGGER, SRC10, 1, 10)
    DEP_FIELD(GICP0_IRQ_TRIGGER, SRC9, 1, 9)
    DEP_FIELD(GICP0_IRQ_TRIGGER, SRC8, 1, 8)
    DEP_FIELD(GICP0_IRQ_TRIGGER, SRC7, 1, 7)
    DEP_FIELD(GICP0_IRQ_TRIGGER, SRC6, 1, 6)
    DEP_FIELD(GICP0_IRQ_TRIGGER, SRC5, 1, 5)
    DEP_FIELD(GICP0_IRQ_TRIGGER, SRC4, 1, 4)
    DEP_FIELD(GICP0_IRQ_TRIGGER, SRC3, 1, 3)
    DEP_FIELD(GICP0_IRQ_TRIGGER, SRC2, 1, 2)
    DEP_FIELD(GICP0_IRQ_TRIGGER, SRC1, 1, 1)
    DEP_FIELD(GICP0_IRQ_TRIGGER, SRC0, 1, 0)
DEP_REG32(GICP1_IRQ_STATUS, 0x14)
    DEP_FIELD(GICP1_IRQ_STATUS, SRC31, 1, 31)
    DEP_FIELD(GICP1_IRQ_STATUS, SRC30, 1, 30)
    DEP_FIELD(GICP1_IRQ_STATUS, SRC29, 1, 29)
    DEP_FIELD(GICP1_IRQ_STATUS, SRC28, 1, 28)
    DEP_FIELD(GICP1_IRQ_STATUS, SRC27, 1, 27)
    DEP_FIELD(GICP1_IRQ_STATUS, SRC26, 1, 26)
    DEP_FIELD(GICP1_IRQ_STATUS, SRC25, 1, 25)
    DEP_FIELD(GICP1_IRQ_STATUS, SRC24, 1, 24)
    DEP_FIELD(GICP1_IRQ_STATUS, SRC23, 1, 23)
    DEP_FIELD(GICP1_IRQ_STATUS, SRC22, 1, 22)
    DEP_FIELD(GICP1_IRQ_STATUS, SRC21, 1, 21)
    DEP_FIELD(GICP1_IRQ_STATUS, SRC20, 1, 20)
    DEP_FIELD(GICP1_IRQ_STATUS, SRC19, 1, 19)
    DEP_FIELD(GICP1_IRQ_STATUS, SRC18, 1, 18)
    DEP_FIELD(GICP1_IRQ_STATUS, SRC17, 1, 17)
    DEP_FIELD(GICP1_IRQ_STATUS, SRC16, 1, 16)
    DEP_FIELD(GICP1_IRQ_STATUS, SRC15, 1, 15)
    DEP_FIELD(GICP1_IRQ_STATUS, SRC14, 1, 14)
    DEP_FIELD(GICP1_IRQ_STATUS, SRC13, 1, 13)
    DEP_FIELD(GICP1_IRQ_STATUS, SRC12, 1, 12)
    DEP_FIELD(GICP1_IRQ_STATUS, SRC11, 1, 11)
    DEP_FIELD(GICP1_IRQ_STATUS, SRC10, 1, 10)
    DEP_FIELD(GICP1_IRQ_STATUS, SRC9, 1, 9)
    DEP_FIELD(GICP1_IRQ_STATUS, SRC8, 1, 8)
    DEP_FIELD(GICP1_IRQ_STATUS, SRC7, 1, 7)
    DEP_FIELD(GICP1_IRQ_STATUS, SRC6, 1, 6)
    DEP_FIELD(GICP1_IRQ_STATUS, SRC5, 1, 5)
    DEP_FIELD(GICP1_IRQ_STATUS, SRC4, 1, 4)
    DEP_FIELD(GICP1_IRQ_STATUS, SRC3, 1, 3)
    DEP_FIELD(GICP1_IRQ_STATUS, SRC2, 1, 2)
    DEP_FIELD(GICP1_IRQ_STATUS, SRC1, 1, 1)
    DEP_FIELD(GICP1_IRQ_STATUS, SRC0, 1, 0)
DEP_REG32(GICP1_IRQ_MASK, 0x18)
    DEP_FIELD(GICP1_IRQ_MASK, SRC31, 1, 31)
    DEP_FIELD(GICP1_IRQ_MASK, SRC30, 1, 30)
    DEP_FIELD(GICP1_IRQ_MASK, SRC29, 1, 29)
    DEP_FIELD(GICP1_IRQ_MASK, SRC28, 1, 28)
    DEP_FIELD(GICP1_IRQ_MASK, SRC27, 1, 27)
    DEP_FIELD(GICP1_IRQ_MASK, SRC26, 1, 26)
    DEP_FIELD(GICP1_IRQ_MASK, SRC25, 1, 25)
    DEP_FIELD(GICP1_IRQ_MASK, SRC24, 1, 24)
    DEP_FIELD(GICP1_IRQ_MASK, SRC23, 1, 23)
    DEP_FIELD(GICP1_IRQ_MASK, SRC22, 1, 22)
    DEP_FIELD(GICP1_IRQ_MASK, SRC21, 1, 21)
    DEP_FIELD(GICP1_IRQ_MASK, SRC20, 1, 20)
    DEP_FIELD(GICP1_IRQ_MASK, SRC19, 1, 19)
    DEP_FIELD(GICP1_IRQ_MASK, SRC18, 1, 18)
    DEP_FIELD(GICP1_IRQ_MASK, SRC17, 1, 17)
    DEP_FIELD(GICP1_IRQ_MASK, SRC16, 1, 16)
    DEP_FIELD(GICP1_IRQ_MASK, SRC15, 1, 15)
    DEP_FIELD(GICP1_IRQ_MASK, SRC14, 1, 14)
    DEP_FIELD(GICP1_IRQ_MASK, SRC13, 1, 13)
    DEP_FIELD(GICP1_IRQ_MASK, SRC12, 1, 12)
    DEP_FIELD(GICP1_IRQ_MASK, SRC11, 1, 11)
    DEP_FIELD(GICP1_IRQ_MASK, SRC10, 1, 10)
    DEP_FIELD(GICP1_IRQ_MASK, SRC9, 1, 9)
    DEP_FIELD(GICP1_IRQ_MASK, SRC8, 1, 8)
    DEP_FIELD(GICP1_IRQ_MASK, SRC7, 1, 7)
    DEP_FIELD(GICP1_IRQ_MASK, SRC6, 1, 6)
    DEP_FIELD(GICP1_IRQ_MASK, SRC5, 1, 5)
    DEP_FIELD(GICP1_IRQ_MASK, SRC4, 1, 4)
    DEP_FIELD(GICP1_IRQ_MASK, SRC3, 1, 3)
    DEP_FIELD(GICP1_IRQ_MASK, SRC2, 1, 2)
    DEP_FIELD(GICP1_IRQ_MASK, SRC1, 1, 1)
    DEP_FIELD(GICP1_IRQ_MASK, SRC0, 1, 0)
DEP_REG32(GICP1_IRQ_ENABLE, 0x1c)
    DEP_FIELD(GICP1_IRQ_ENABLE, SRC31, 1, 31)
    DEP_FIELD(GICP1_IRQ_ENABLE, SRC30, 1, 30)
    DEP_FIELD(GICP1_IRQ_ENABLE, SRC29, 1, 29)
    DEP_FIELD(GICP1_IRQ_ENABLE, SRC28, 1, 28)
    DEP_FIELD(GICP1_IRQ_ENABLE, SRC27, 1, 27)
    DEP_FIELD(GICP1_IRQ_ENABLE, SRC26, 1, 26)
    DEP_FIELD(GICP1_IRQ_ENABLE, SRC25, 1, 25)
    DEP_FIELD(GICP1_IRQ_ENABLE, SRC24, 1, 24)
    DEP_FIELD(GICP1_IRQ_ENABLE, SRC23, 1, 23)
    DEP_FIELD(GICP1_IRQ_ENABLE, SRC22, 1, 22)
    DEP_FIELD(GICP1_IRQ_ENABLE, SRC21, 1, 21)
    DEP_FIELD(GICP1_IRQ_ENABLE, SRC20, 1, 20)
    DEP_FIELD(GICP1_IRQ_ENABLE, SRC19, 1, 19)
    DEP_FIELD(GICP1_IRQ_ENABLE, SRC18, 1, 18)
    DEP_FIELD(GICP1_IRQ_ENABLE, SRC17, 1, 17)
    DEP_FIELD(GICP1_IRQ_ENABLE, SRC16, 1, 16)
    DEP_FIELD(GICP1_IRQ_ENABLE, SRC15, 1, 15)
    DEP_FIELD(GICP1_IRQ_ENABLE, SRC14, 1, 14)
    DEP_FIELD(GICP1_IRQ_ENABLE, SRC13, 1, 13)
    DEP_FIELD(GICP1_IRQ_ENABLE, SRC12, 1, 12)
    DEP_FIELD(GICP1_IRQ_ENABLE, SRC11, 1, 11)
    DEP_FIELD(GICP1_IRQ_ENABLE, SRC10, 1, 10)
    DEP_FIELD(GICP1_IRQ_ENABLE, SRC9, 1, 9)
    DEP_FIELD(GICP1_IRQ_ENABLE, SRC8, 1, 8)
    DEP_FIELD(GICP1_IRQ_ENABLE, SRC7, 1, 7)
    DEP_FIELD(GICP1_IRQ_ENABLE, SRC6, 1, 6)
    DEP_FIELD(GICP1_IRQ_ENABLE, SRC5, 1, 5)
    DEP_FIELD(GICP1_IRQ_ENABLE, SRC4, 1, 4)
    DEP_FIELD(GICP1_IRQ_ENABLE, SRC3, 1, 3)
    DEP_FIELD(GICP1_IRQ_ENABLE, SRC2, 1, 2)
    DEP_FIELD(GICP1_IRQ_ENABLE, SRC1, 1, 1)
    DEP_FIELD(GICP1_IRQ_ENABLE, SRC0, 1, 0)
DEP_REG32(GICP1_IRQ_DISABLE, 0x20)
    DEP_FIELD(GICP1_IRQ_DISABLE, SRC31, 1, 31)
    DEP_FIELD(GICP1_IRQ_DISABLE, SRC30, 1, 30)
    DEP_FIELD(GICP1_IRQ_DISABLE, SRC29, 1, 29)
    DEP_FIELD(GICP1_IRQ_DISABLE, SRC28, 1, 28)
    DEP_FIELD(GICP1_IRQ_DISABLE, SRC27, 1, 27)
    DEP_FIELD(GICP1_IRQ_DISABLE, SRC26, 1, 26)
    DEP_FIELD(GICP1_IRQ_DISABLE, SRC25, 1, 25)
    DEP_FIELD(GICP1_IRQ_DISABLE, SRC24, 1, 24)
    DEP_FIELD(GICP1_IRQ_DISABLE, SRC23, 1, 23)
    DEP_FIELD(GICP1_IRQ_DISABLE, SRC22, 1, 22)
    DEP_FIELD(GICP1_IRQ_DISABLE, SRC21, 1, 21)
    DEP_FIELD(GICP1_IRQ_DISABLE, SRC20, 1, 20)
    DEP_FIELD(GICP1_IRQ_DISABLE, SRC19, 1, 19)
    DEP_FIELD(GICP1_IRQ_DISABLE, SRC18, 1, 18)
    DEP_FIELD(GICP1_IRQ_DISABLE, SRC17, 1, 17)
    DEP_FIELD(GICP1_IRQ_DISABLE, SRC16, 1, 16)
    DEP_FIELD(GICP1_IRQ_DISABLE, SRC15, 1, 15)
    DEP_FIELD(GICP1_IRQ_DISABLE, SRC14, 1, 14)
    DEP_FIELD(GICP1_IRQ_DISABLE, SRC13, 1, 13)
    DEP_FIELD(GICP1_IRQ_DISABLE, SRC12, 1, 12)
    DEP_FIELD(GICP1_IRQ_DISABLE, SRC11, 1, 11)
    DEP_FIELD(GICP1_IRQ_DISABLE, SRC10, 1, 10)
    DEP_FIELD(GICP1_IRQ_DISABLE, SRC9, 1, 9)
    DEP_FIELD(GICP1_IRQ_DISABLE, SRC8, 1, 8)
    DEP_FIELD(GICP1_IRQ_DISABLE, SRC7, 1, 7)
    DEP_FIELD(GICP1_IRQ_DISABLE, SRC6, 1, 6)
    DEP_FIELD(GICP1_IRQ_DISABLE, SRC5, 1, 5)
    DEP_FIELD(GICP1_IRQ_DISABLE, SRC4, 1, 4)
    DEP_FIELD(GICP1_IRQ_DISABLE, SRC3, 1, 3)
    DEP_FIELD(GICP1_IRQ_DISABLE, SRC2, 1, 2)
    DEP_FIELD(GICP1_IRQ_DISABLE, SRC1, 1, 1)
    DEP_FIELD(GICP1_IRQ_DISABLE, SRC0, 1, 0)
DEP_REG32(GICP1_IRQ_TRIGGER, 0x24)
    DEP_FIELD(GICP1_IRQ_TRIGGER, SRC31, 1, 31)
    DEP_FIELD(GICP1_IRQ_TRIGGER, SRC30, 1, 30)
    DEP_FIELD(GICP1_IRQ_TRIGGER, SRC29, 1, 29)
    DEP_FIELD(GICP1_IRQ_TRIGGER, SRC28, 1, 28)
    DEP_FIELD(GICP1_IRQ_TRIGGER, SRC27, 1, 27)
    DEP_FIELD(GICP1_IRQ_TRIGGER, SRC26, 1, 26)
    DEP_FIELD(GICP1_IRQ_TRIGGER, SRC25, 1, 25)
    DEP_FIELD(GICP1_IRQ_TRIGGER, SRC24, 1, 24)
    DEP_FIELD(GICP1_IRQ_TRIGGER, SRC23, 1, 23)
    DEP_FIELD(GICP1_IRQ_TRIGGER, SRC22, 1, 22)
    DEP_FIELD(GICP1_IRQ_TRIGGER, SRC21, 1, 21)
    DEP_FIELD(GICP1_IRQ_TRIGGER, SRC20, 1, 20)
    DEP_FIELD(GICP1_IRQ_TRIGGER, SRC19, 1, 19)
    DEP_FIELD(GICP1_IRQ_TRIGGER, SRC18, 1, 18)
    DEP_FIELD(GICP1_IRQ_TRIGGER, SRC17, 1, 17)
    DEP_FIELD(GICP1_IRQ_TRIGGER, SRC16, 1, 16)
    DEP_FIELD(GICP1_IRQ_TRIGGER, SRC15, 1, 15)
    DEP_FIELD(GICP1_IRQ_TRIGGER, SRC14, 1, 14)
    DEP_FIELD(GICP1_IRQ_TRIGGER, SRC13, 1, 13)
    DEP_FIELD(GICP1_IRQ_TRIGGER, SRC12, 1, 12)
    DEP_FIELD(GICP1_IRQ_TRIGGER, SRC11, 1, 11)
    DEP_FIELD(GICP1_IRQ_TRIGGER, SRC10, 1, 10)
    DEP_FIELD(GICP1_IRQ_TRIGGER, SRC9, 1, 9)
    DEP_FIELD(GICP1_IRQ_TRIGGER, SRC8, 1, 8)
    DEP_FIELD(GICP1_IRQ_TRIGGER, SRC7, 1, 7)
    DEP_FIELD(GICP1_IRQ_TRIGGER, SRC6, 1, 6)
    DEP_FIELD(GICP1_IRQ_TRIGGER, SRC5, 1, 5)
    DEP_FIELD(GICP1_IRQ_TRIGGER, SRC4, 1, 4)
    DEP_FIELD(GICP1_IRQ_TRIGGER, SRC3, 1, 3)
    DEP_FIELD(GICP1_IRQ_TRIGGER, SRC2, 1, 2)
    DEP_FIELD(GICP1_IRQ_TRIGGER, SRC1, 1, 1)
    DEP_FIELD(GICP1_IRQ_TRIGGER, SRC0, 1, 0)
DEP_REG32(GICP2_IRQ_STATUS, 0x28)
    DEP_FIELD(GICP2_IRQ_STATUS, SRC31, 1, 31)
    DEP_FIELD(GICP2_IRQ_STATUS, SRC30, 1, 30)
    DEP_FIELD(GICP2_IRQ_STATUS, SRC29, 1, 29)
    DEP_FIELD(GICP2_IRQ_STATUS, SRC28, 1, 28)
    DEP_FIELD(GICP2_IRQ_STATUS, SRC27, 1, 27)
    DEP_FIELD(GICP2_IRQ_STATUS, SRC26, 1, 26)
    DEP_FIELD(GICP2_IRQ_STATUS, SRC25, 1, 25)
    DEP_FIELD(GICP2_IRQ_STATUS, SRC24, 1, 24)
    DEP_FIELD(GICP2_IRQ_STATUS, SRC23, 1, 23)
    DEP_FIELD(GICP2_IRQ_STATUS, SRC22, 1, 22)
    DEP_FIELD(GICP2_IRQ_STATUS, SRC21, 1, 21)
    DEP_FIELD(GICP2_IRQ_STATUS, SRC20, 1, 20)
    DEP_FIELD(GICP2_IRQ_STATUS, SRC19, 1, 19)
    DEP_FIELD(GICP2_IRQ_STATUS, SRC18, 1, 18)
    DEP_FIELD(GICP2_IRQ_STATUS, SRC17, 1, 17)
    DEP_FIELD(GICP2_IRQ_STATUS, SRC16, 1, 16)
    DEP_FIELD(GICP2_IRQ_STATUS, SRC15, 1, 15)
    DEP_FIELD(GICP2_IRQ_STATUS, SRC14, 1, 14)
    DEP_FIELD(GICP2_IRQ_STATUS, SRC13, 1, 13)
    DEP_FIELD(GICP2_IRQ_STATUS, SRC12, 1, 12)
    DEP_FIELD(GICP2_IRQ_STATUS, SRC11, 1, 11)
    DEP_FIELD(GICP2_IRQ_STATUS, SRC10, 1, 10)
    DEP_FIELD(GICP2_IRQ_STATUS, SRC9, 1, 9)
    DEP_FIELD(GICP2_IRQ_STATUS, SRC8, 1, 8)
    DEP_FIELD(GICP2_IRQ_STATUS, SRC7, 1, 7)
    DEP_FIELD(GICP2_IRQ_STATUS, SRC6, 1, 6)
    DEP_FIELD(GICP2_IRQ_STATUS, SRC5, 1, 5)
    DEP_FIELD(GICP2_IRQ_STATUS, SRC4, 1, 4)
    DEP_FIELD(GICP2_IRQ_STATUS, SRC3, 1, 3)
    DEP_FIELD(GICP2_IRQ_STATUS, SRC2, 1, 2)
    DEP_FIELD(GICP2_IRQ_STATUS, SRC1, 1, 1)
    DEP_FIELD(GICP2_IRQ_STATUS, SRC0, 1, 0)
DEP_REG32(GICP2_IRQ_MASK, 0x2c)
    DEP_FIELD(GICP2_IRQ_MASK, SRC31, 1, 31)
    DEP_FIELD(GICP2_IRQ_MASK, SRC30, 1, 30)
    DEP_FIELD(GICP2_IRQ_MASK, SRC29, 1, 29)
    DEP_FIELD(GICP2_IRQ_MASK, SRC28, 1, 28)
    DEP_FIELD(GICP2_IRQ_MASK, SRC27, 1, 27)
    DEP_FIELD(GICP2_IRQ_MASK, SRC26, 1, 26)
    DEP_FIELD(GICP2_IRQ_MASK, SRC25, 1, 25)
    DEP_FIELD(GICP2_IRQ_MASK, SRC24, 1, 24)
    DEP_FIELD(GICP2_IRQ_MASK, SRC23, 1, 23)
    DEP_FIELD(GICP2_IRQ_MASK, SRC22, 1, 22)
    DEP_FIELD(GICP2_IRQ_MASK, SRC21, 1, 21)
    DEP_FIELD(GICP2_IRQ_MASK, SRC20, 1, 20)
    DEP_FIELD(GICP2_IRQ_MASK, SRC19, 1, 19)
    DEP_FIELD(GICP2_IRQ_MASK, SRC18, 1, 18)
    DEP_FIELD(GICP2_IRQ_MASK, SRC17, 1, 17)
    DEP_FIELD(GICP2_IRQ_MASK, SRC16, 1, 16)
    DEP_FIELD(GICP2_IRQ_MASK, SRC15, 1, 15)
    DEP_FIELD(GICP2_IRQ_MASK, SRC14, 1, 14)
    DEP_FIELD(GICP2_IRQ_MASK, SRC13, 1, 13)
    DEP_FIELD(GICP2_IRQ_MASK, SRC12, 1, 12)
    DEP_FIELD(GICP2_IRQ_MASK, SRC11, 1, 11)
    DEP_FIELD(GICP2_IRQ_MASK, SRC10, 1, 10)
    DEP_FIELD(GICP2_IRQ_MASK, SRC9, 1, 9)
    DEP_FIELD(GICP2_IRQ_MASK, SRC8, 1, 8)
    DEP_FIELD(GICP2_IRQ_MASK, SRC7, 1, 7)
    DEP_FIELD(GICP2_IRQ_MASK, SRC6, 1, 6)
    DEP_FIELD(GICP2_IRQ_MASK, SRC5, 1, 5)
    DEP_FIELD(GICP2_IRQ_MASK, SRC4, 1, 4)
    DEP_FIELD(GICP2_IRQ_MASK, SRC3, 1, 3)
    DEP_FIELD(GICP2_IRQ_MASK, SRC2, 1, 2)
    DEP_FIELD(GICP2_IRQ_MASK, SRC1, 1, 1)
    DEP_FIELD(GICP2_IRQ_MASK, SRC0, 1, 0)
DEP_REG32(GICP2_IRQ_ENABLE, 0x30)
    DEP_FIELD(GICP2_IRQ_ENABLE, SRC31, 1, 31)
    DEP_FIELD(GICP2_IRQ_ENABLE, SRC30, 1, 30)
    DEP_FIELD(GICP2_IRQ_ENABLE, SRC29, 1, 29)
    DEP_FIELD(GICP2_IRQ_ENABLE, SRC28, 1, 28)
    DEP_FIELD(GICP2_IRQ_ENABLE, SRC27, 1, 27)
    DEP_FIELD(GICP2_IRQ_ENABLE, SRC26, 1, 26)
    DEP_FIELD(GICP2_IRQ_ENABLE, SRC25, 1, 25)
    DEP_FIELD(GICP2_IRQ_ENABLE, SRC24, 1, 24)
    DEP_FIELD(GICP2_IRQ_ENABLE, SRC23, 1, 23)
    DEP_FIELD(GICP2_IRQ_ENABLE, SRC22, 1, 22)
    DEP_FIELD(GICP2_IRQ_ENABLE, SRC21, 1, 21)
    DEP_FIELD(GICP2_IRQ_ENABLE, SRC20, 1, 20)
    DEP_FIELD(GICP2_IRQ_ENABLE, SRC19, 1, 19)
    DEP_FIELD(GICP2_IRQ_ENABLE, SRC18, 1, 18)
    DEP_FIELD(GICP2_IRQ_ENABLE, SRC17, 1, 17)
    DEP_FIELD(GICP2_IRQ_ENABLE, SRC16, 1, 16)
    DEP_FIELD(GICP2_IRQ_ENABLE, SRC15, 1, 15)
    DEP_FIELD(GICP2_IRQ_ENABLE, SRC14, 1, 14)
    DEP_FIELD(GICP2_IRQ_ENABLE, SRC13, 1, 13)
    DEP_FIELD(GICP2_IRQ_ENABLE, SRC12, 1, 12)
    DEP_FIELD(GICP2_IRQ_ENABLE, SRC11, 1, 11)
    DEP_FIELD(GICP2_IRQ_ENABLE, SRC10, 1, 10)
    DEP_FIELD(GICP2_IRQ_ENABLE, SRC9, 1, 9)
    DEP_FIELD(GICP2_IRQ_ENABLE, SRC8, 1, 8)
    DEP_FIELD(GICP2_IRQ_ENABLE, SRC7, 1, 7)
    DEP_FIELD(GICP2_IRQ_ENABLE, SRC6, 1, 6)
    DEP_FIELD(GICP2_IRQ_ENABLE, SRC5, 1, 5)
    DEP_FIELD(GICP2_IRQ_ENABLE, SRC4, 1, 4)
    DEP_FIELD(GICP2_IRQ_ENABLE, SRC3, 1, 3)
    DEP_FIELD(GICP2_IRQ_ENABLE, SRC2, 1, 2)
    DEP_FIELD(GICP2_IRQ_ENABLE, SRC1, 1, 1)
    DEP_FIELD(GICP2_IRQ_ENABLE, SRC0, 1, 0)
DEP_REG32(GICP2_IRQ_DISABLE, 0x34)
    DEP_FIELD(GICP2_IRQ_DISABLE, SRC31, 1, 31)
    DEP_FIELD(GICP2_IRQ_DISABLE, SRC30, 1, 30)
    DEP_FIELD(GICP2_IRQ_DISABLE, SRC29, 1, 29)
    DEP_FIELD(GICP2_IRQ_DISABLE, SRC28, 1, 28)
    DEP_FIELD(GICP2_IRQ_DISABLE, SRC27, 1, 27)
    DEP_FIELD(GICP2_IRQ_DISABLE, SRC26, 1, 26)
    DEP_FIELD(GICP2_IRQ_DISABLE, SRC25, 1, 25)
    DEP_FIELD(GICP2_IRQ_DISABLE, SRC24, 1, 24)
    DEP_FIELD(GICP2_IRQ_DISABLE, SRC23, 1, 23)
    DEP_FIELD(GICP2_IRQ_DISABLE, SRC22, 1, 22)
    DEP_FIELD(GICP2_IRQ_DISABLE, SRC21, 1, 21)
    DEP_FIELD(GICP2_IRQ_DISABLE, SRC20, 1, 20)
    DEP_FIELD(GICP2_IRQ_DISABLE, SRC19, 1, 19)
    DEP_FIELD(GICP2_IRQ_DISABLE, SRC18, 1, 18)
    DEP_FIELD(GICP2_IRQ_DISABLE, SRC17, 1, 17)
    DEP_FIELD(GICP2_IRQ_DISABLE, SRC16, 1, 16)
    DEP_FIELD(GICP2_IRQ_DISABLE, SRC15, 1, 15)
    DEP_FIELD(GICP2_IRQ_DISABLE, SRC14, 1, 14)
    DEP_FIELD(GICP2_IRQ_DISABLE, SRC13, 1, 13)
    DEP_FIELD(GICP2_IRQ_DISABLE, SRC12, 1, 12)
    DEP_FIELD(GICP2_IRQ_DISABLE, SRC11, 1, 11)
    DEP_FIELD(GICP2_IRQ_DISABLE, SRC10, 1, 10)
    DEP_FIELD(GICP2_IRQ_DISABLE, SRC9, 1, 9)
    DEP_FIELD(GICP2_IRQ_DISABLE, SRC8, 1, 8)
    DEP_FIELD(GICP2_IRQ_DISABLE, SRC7, 1, 7)
    DEP_FIELD(GICP2_IRQ_DISABLE, SRC6, 1, 6)
    DEP_FIELD(GICP2_IRQ_DISABLE, SRC5, 1, 5)
    DEP_FIELD(GICP2_IRQ_DISABLE, SRC4, 1, 4)
    DEP_FIELD(GICP2_IRQ_DISABLE, SRC3, 1, 3)
    DEP_FIELD(GICP2_IRQ_DISABLE, SRC2, 1, 2)
    DEP_FIELD(GICP2_IRQ_DISABLE, SRC1, 1, 1)
    DEP_FIELD(GICP2_IRQ_DISABLE, SRC0, 1, 0)
DEP_REG32(GICP2_IRQ_TRIGGER, 0x38)
    DEP_FIELD(GICP2_IRQ_TRIGGER, SRC31, 1, 31)
    DEP_FIELD(GICP2_IRQ_TRIGGER, SRC30, 1, 30)
    DEP_FIELD(GICP2_IRQ_TRIGGER, SRC29, 1, 29)
    DEP_FIELD(GICP2_IRQ_TRIGGER, SRC28, 1, 28)
    DEP_FIELD(GICP2_IRQ_TRIGGER, SRC27, 1, 27)
    DEP_FIELD(GICP2_IRQ_TRIGGER, SRC26, 1, 26)
    DEP_FIELD(GICP2_IRQ_TRIGGER, SRC25, 1, 25)
    DEP_FIELD(GICP2_IRQ_TRIGGER, SRC24, 1, 24)
    DEP_FIELD(GICP2_IRQ_TRIGGER, SRC23, 1, 23)
    DEP_FIELD(GICP2_IRQ_TRIGGER, SRC22, 1, 22)
    DEP_FIELD(GICP2_IRQ_TRIGGER, SRC21, 1, 21)
    DEP_FIELD(GICP2_IRQ_TRIGGER, SRC20, 1, 20)
    DEP_FIELD(GICP2_IRQ_TRIGGER, SRC19, 1, 19)
    DEP_FIELD(GICP2_IRQ_TRIGGER, SRC18, 1, 18)
    DEP_FIELD(GICP2_IRQ_TRIGGER, SRC17, 1, 17)
    DEP_FIELD(GICP2_IRQ_TRIGGER, SRC16, 1, 16)
    DEP_FIELD(GICP2_IRQ_TRIGGER, SRC15, 1, 15)
    DEP_FIELD(GICP2_IRQ_TRIGGER, SRC14, 1, 14)
    DEP_FIELD(GICP2_IRQ_TRIGGER, SRC13, 1, 13)
    DEP_FIELD(GICP2_IRQ_TRIGGER, SRC12, 1, 12)
    DEP_FIELD(GICP2_IRQ_TRIGGER, SRC11, 1, 11)
    DEP_FIELD(GICP2_IRQ_TRIGGER, SRC10, 1, 10)
    DEP_FIELD(GICP2_IRQ_TRIGGER, SRC9, 1, 9)
    DEP_FIELD(GICP2_IRQ_TRIGGER, SRC8, 1, 8)
    DEP_FIELD(GICP2_IRQ_TRIGGER, SRC7, 1, 7)
    DEP_FIELD(GICP2_IRQ_TRIGGER, SRC6, 1, 6)
    DEP_FIELD(GICP2_IRQ_TRIGGER, SRC5, 1, 5)
    DEP_FIELD(GICP2_IRQ_TRIGGER, SRC4, 1, 4)
    DEP_FIELD(GICP2_IRQ_TRIGGER, SRC3, 1, 3)
    DEP_FIELD(GICP2_IRQ_TRIGGER, SRC2, 1, 2)
    DEP_FIELD(GICP2_IRQ_TRIGGER, SRC1, 1, 1)
    DEP_FIELD(GICP2_IRQ_TRIGGER, SRC0, 1, 0)
DEP_REG32(GICP3_IRQ_STATUS, 0x3c)
    DEP_FIELD(GICP3_IRQ_STATUS, SRC31, 1, 31)
    DEP_FIELD(GICP3_IRQ_STATUS, SRC30, 1, 30)
    DEP_FIELD(GICP3_IRQ_STATUS, SRC29, 1, 29)
    DEP_FIELD(GICP3_IRQ_STATUS, SRC28, 1, 28)
    DEP_FIELD(GICP3_IRQ_STATUS, SRC27, 1, 27)
    DEP_FIELD(GICP3_IRQ_STATUS, SRC26, 1, 26)
    DEP_FIELD(GICP3_IRQ_STATUS, SRC25, 1, 25)
    DEP_FIELD(GICP3_IRQ_STATUS, SRC24, 1, 24)
    DEP_FIELD(GICP3_IRQ_STATUS, SRC23, 1, 23)
    DEP_FIELD(GICP3_IRQ_STATUS, SRC22, 1, 22)
    DEP_FIELD(GICP3_IRQ_STATUS, SRC21, 1, 21)
    DEP_FIELD(GICP3_IRQ_STATUS, SRC20, 1, 20)
    DEP_FIELD(GICP3_IRQ_STATUS, SRC19, 1, 19)
    DEP_FIELD(GICP3_IRQ_STATUS, SRC18, 1, 18)
    DEP_FIELD(GICP3_IRQ_STATUS, SRC17, 1, 17)
    DEP_FIELD(GICP3_IRQ_STATUS, SRC16, 1, 16)
    DEP_FIELD(GICP3_IRQ_STATUS, SRC15, 1, 15)
    DEP_FIELD(GICP3_IRQ_STATUS, SRC14, 1, 14)
    DEP_FIELD(GICP3_IRQ_STATUS, SRC13, 1, 13)
    DEP_FIELD(GICP3_IRQ_STATUS, SRC12, 1, 12)
    DEP_FIELD(GICP3_IRQ_STATUS, SRC11, 1, 11)
    DEP_FIELD(GICP3_IRQ_STATUS, SRC10, 1, 10)
    DEP_FIELD(GICP3_IRQ_STATUS, SRC9, 1, 9)
    DEP_FIELD(GICP3_IRQ_STATUS, SRC8, 1, 8)
    DEP_FIELD(GICP3_IRQ_STATUS, SRC7, 1, 7)
    DEP_FIELD(GICP3_IRQ_STATUS, SRC6, 1, 6)
    DEP_FIELD(GICP3_IRQ_STATUS, SRC5, 1, 5)
    DEP_FIELD(GICP3_IRQ_STATUS, SRC4, 1, 4)
    DEP_FIELD(GICP3_IRQ_STATUS, SRC3, 1, 3)
    DEP_FIELD(GICP3_IRQ_STATUS, SRC2, 1, 2)
    DEP_FIELD(GICP3_IRQ_STATUS, SRC1, 1, 1)
    DEP_FIELD(GICP3_IRQ_STATUS, SRC0, 1, 0)
DEP_REG32(GICP3_IRQ_MASK, 0x40)
    DEP_FIELD(GICP3_IRQ_MASK, SRC31, 1, 31)
    DEP_FIELD(GICP3_IRQ_MASK, SRC30, 1, 30)
    DEP_FIELD(GICP3_IRQ_MASK, SRC29, 1, 29)
    DEP_FIELD(GICP3_IRQ_MASK, SRC28, 1, 28)
    DEP_FIELD(GICP3_IRQ_MASK, SRC27, 1, 27)
    DEP_FIELD(GICP3_IRQ_MASK, SRC26, 1, 26)
    DEP_FIELD(GICP3_IRQ_MASK, SRC25, 1, 25)
    DEP_FIELD(GICP3_IRQ_MASK, SRC24, 1, 24)
    DEP_FIELD(GICP3_IRQ_MASK, SRC23, 1, 23)
    DEP_FIELD(GICP3_IRQ_MASK, SRC22, 1, 22)
    DEP_FIELD(GICP3_IRQ_MASK, SRC21, 1, 21)
    DEP_FIELD(GICP3_IRQ_MASK, SRC20, 1, 20)
    DEP_FIELD(GICP3_IRQ_MASK, SRC19, 1, 19)
    DEP_FIELD(GICP3_IRQ_MASK, SRC18, 1, 18)
    DEP_FIELD(GICP3_IRQ_MASK, SRC17, 1, 17)
    DEP_FIELD(GICP3_IRQ_MASK, SRC16, 1, 16)
    DEP_FIELD(GICP3_IRQ_MASK, SRC15, 1, 15)
    DEP_FIELD(GICP3_IRQ_MASK, SRC14, 1, 14)
    DEP_FIELD(GICP3_IRQ_MASK, SRC13, 1, 13)
    DEP_FIELD(GICP3_IRQ_MASK, SRC12, 1, 12)
    DEP_FIELD(GICP3_IRQ_MASK, SRC11, 1, 11)
    DEP_FIELD(GICP3_IRQ_MASK, SRC10, 1, 10)
    DEP_FIELD(GICP3_IRQ_MASK, SRC9, 1, 9)
    DEP_FIELD(GICP3_IRQ_MASK, SRC8, 1, 8)
    DEP_FIELD(GICP3_IRQ_MASK, SRC7, 1, 7)
    DEP_FIELD(GICP3_IRQ_MASK, SRC6, 1, 6)
    DEP_FIELD(GICP3_IRQ_MASK, SRC5, 1, 5)
    DEP_FIELD(GICP3_IRQ_MASK, SRC4, 1, 4)
    DEP_FIELD(GICP3_IRQ_MASK, SRC3, 1, 3)
    DEP_FIELD(GICP3_IRQ_MASK, SRC2, 1, 2)
    DEP_FIELD(GICP3_IRQ_MASK, SRC1, 1, 1)
    DEP_FIELD(GICP3_IRQ_MASK, SRC0, 1, 0)
DEP_REG32(GICP3_IRQ_ENABLE, 0x44)
    DEP_FIELD(GICP3_IRQ_ENABLE, SRC31, 1, 31)
    DEP_FIELD(GICP3_IRQ_ENABLE, SRC30, 1, 30)
    DEP_FIELD(GICP3_IRQ_ENABLE, SRC29, 1, 29)
    DEP_FIELD(GICP3_IRQ_ENABLE, SRC28, 1, 28)
    DEP_FIELD(GICP3_IRQ_ENABLE, SRC27, 1, 27)
    DEP_FIELD(GICP3_IRQ_ENABLE, SRC26, 1, 26)
    DEP_FIELD(GICP3_IRQ_ENABLE, SRC25, 1, 25)
    DEP_FIELD(GICP3_IRQ_ENABLE, SRC24, 1, 24)
    DEP_FIELD(GICP3_IRQ_ENABLE, SRC23, 1, 23)
    DEP_FIELD(GICP3_IRQ_ENABLE, SRC22, 1, 22)
    DEP_FIELD(GICP3_IRQ_ENABLE, SRC21, 1, 21)
    DEP_FIELD(GICP3_IRQ_ENABLE, SRC20, 1, 20)
    DEP_FIELD(GICP3_IRQ_ENABLE, SRC19, 1, 19)
    DEP_FIELD(GICP3_IRQ_ENABLE, SRC18, 1, 18)
    DEP_FIELD(GICP3_IRQ_ENABLE, SRC17, 1, 17)
    DEP_FIELD(GICP3_IRQ_ENABLE, SRC16, 1, 16)
    DEP_FIELD(GICP3_IRQ_ENABLE, SRC15, 1, 15)
    DEP_FIELD(GICP3_IRQ_ENABLE, SRC14, 1, 14)
    DEP_FIELD(GICP3_IRQ_ENABLE, SRC13, 1, 13)
    DEP_FIELD(GICP3_IRQ_ENABLE, SRC12, 1, 12)
    DEP_FIELD(GICP3_IRQ_ENABLE, SRC11, 1, 11)
    DEP_FIELD(GICP3_IRQ_ENABLE, SRC10, 1, 10)
    DEP_FIELD(GICP3_IRQ_ENABLE, SRC9, 1, 9)
    DEP_FIELD(GICP3_IRQ_ENABLE, SRC8, 1, 8)
    DEP_FIELD(GICP3_IRQ_ENABLE, SRC7, 1, 7)
    DEP_FIELD(GICP3_IRQ_ENABLE, SRC6, 1, 6)
    DEP_FIELD(GICP3_IRQ_ENABLE, SRC5, 1, 5)
    DEP_FIELD(GICP3_IRQ_ENABLE, SRC4, 1, 4)
    DEP_FIELD(GICP3_IRQ_ENABLE, SRC3, 1, 3)
    DEP_FIELD(GICP3_IRQ_ENABLE, SRC2, 1, 2)
    DEP_FIELD(GICP3_IRQ_ENABLE, SRC1, 1, 1)
    DEP_FIELD(GICP3_IRQ_ENABLE, SRC0, 1, 0)
DEP_REG32(GICP3_IRQ_DISABLE, 0x48)
    DEP_FIELD(GICP3_IRQ_DISABLE, SRC31, 1, 31)
    DEP_FIELD(GICP3_IRQ_DISABLE, SRC30, 1, 30)
    DEP_FIELD(GICP3_IRQ_DISABLE, SRC29, 1, 29)
    DEP_FIELD(GICP3_IRQ_DISABLE, SRC28, 1, 28)
    DEP_FIELD(GICP3_IRQ_DISABLE, SRC27, 1, 27)
    DEP_FIELD(GICP3_IRQ_DISABLE, SRC26, 1, 26)
    DEP_FIELD(GICP3_IRQ_DISABLE, SRC25, 1, 25)
    DEP_FIELD(GICP3_IRQ_DISABLE, SRC24, 1, 24)
    DEP_FIELD(GICP3_IRQ_DISABLE, SRC23, 1, 23)
    DEP_FIELD(GICP3_IRQ_DISABLE, SRC22, 1, 22)
    DEP_FIELD(GICP3_IRQ_DISABLE, SRC21, 1, 21)
    DEP_FIELD(GICP3_IRQ_DISABLE, SRC20, 1, 20)
    DEP_FIELD(GICP3_IRQ_DISABLE, SRC19, 1, 19)
    DEP_FIELD(GICP3_IRQ_DISABLE, SRC18, 1, 18)
    DEP_FIELD(GICP3_IRQ_DISABLE, SRC17, 1, 17)
    DEP_FIELD(GICP3_IRQ_DISABLE, SRC16, 1, 16)
    DEP_FIELD(GICP3_IRQ_DISABLE, SRC15, 1, 15)
    DEP_FIELD(GICP3_IRQ_DISABLE, SRC14, 1, 14)
    DEP_FIELD(GICP3_IRQ_DISABLE, SRC13, 1, 13)
    DEP_FIELD(GICP3_IRQ_DISABLE, SRC12, 1, 12)
    DEP_FIELD(GICP3_IRQ_DISABLE, SRC11, 1, 11)
    DEP_FIELD(GICP3_IRQ_DISABLE, SRC10, 1, 10)
    DEP_FIELD(GICP3_IRQ_DISABLE, SRC9, 1, 9)
    DEP_FIELD(GICP3_IRQ_DISABLE, SRC8, 1, 8)
    DEP_FIELD(GICP3_IRQ_DISABLE, SRC7, 1, 7)
    DEP_FIELD(GICP3_IRQ_DISABLE, SRC6, 1, 6)
    DEP_FIELD(GICP3_IRQ_DISABLE, SRC5, 1, 5)
    DEP_FIELD(GICP3_IRQ_DISABLE, SRC4, 1, 4)
    DEP_FIELD(GICP3_IRQ_DISABLE, SRC3, 1, 3)
    DEP_FIELD(GICP3_IRQ_DISABLE, SRC2, 1, 2)
    DEP_FIELD(GICP3_IRQ_DISABLE, SRC1, 1, 1)
    DEP_FIELD(GICP3_IRQ_DISABLE, SRC0, 1, 0)
DEP_REG32(GICP3_IRQ_TRIGGER, 0x4c)
    DEP_FIELD(GICP3_IRQ_TRIGGER, SRC31, 1, 31)
    DEP_FIELD(GICP3_IRQ_TRIGGER, SRC30, 1, 30)
    DEP_FIELD(GICP3_IRQ_TRIGGER, SRC29, 1, 29)
    DEP_FIELD(GICP3_IRQ_TRIGGER, SRC28, 1, 28)
    DEP_FIELD(GICP3_IRQ_TRIGGER, SRC27, 1, 27)
    DEP_FIELD(GICP3_IRQ_TRIGGER, SRC26, 1, 26)
    DEP_FIELD(GICP3_IRQ_TRIGGER, SRC25, 1, 25)
    DEP_FIELD(GICP3_IRQ_TRIGGER, SRC24, 1, 24)
    DEP_FIELD(GICP3_IRQ_TRIGGER, SRC23, 1, 23)
    DEP_FIELD(GICP3_IRQ_TRIGGER, SRC22, 1, 22)
    DEP_FIELD(GICP3_IRQ_TRIGGER, SRC21, 1, 21)
    DEP_FIELD(GICP3_IRQ_TRIGGER, SRC20, 1, 20)
    DEP_FIELD(GICP3_IRQ_TRIGGER, SRC19, 1, 19)
    DEP_FIELD(GICP3_IRQ_TRIGGER, SRC18, 1, 18)
    DEP_FIELD(GICP3_IRQ_TRIGGER, SRC17, 1, 17)
    DEP_FIELD(GICP3_IRQ_TRIGGER, SRC16, 1, 16)
    DEP_FIELD(GICP3_IRQ_TRIGGER, SRC15, 1, 15)
    DEP_FIELD(GICP3_IRQ_TRIGGER, SRC14, 1, 14)
    DEP_FIELD(GICP3_IRQ_TRIGGER, SRC13, 1, 13)
    DEP_FIELD(GICP3_IRQ_TRIGGER, SRC12, 1, 12)
    DEP_FIELD(GICP3_IRQ_TRIGGER, SRC11, 1, 11)
    DEP_FIELD(GICP3_IRQ_TRIGGER, SRC10, 1, 10)
    DEP_FIELD(GICP3_IRQ_TRIGGER, SRC9, 1, 9)
    DEP_FIELD(GICP3_IRQ_TRIGGER, SRC8, 1, 8)
    DEP_FIELD(GICP3_IRQ_TRIGGER, SRC7, 1, 7)
    DEP_FIELD(GICP3_IRQ_TRIGGER, SRC6, 1, 6)
    DEP_FIELD(GICP3_IRQ_TRIGGER, SRC5, 1, 5)
    DEP_FIELD(GICP3_IRQ_TRIGGER, SRC4, 1, 4)
    DEP_FIELD(GICP3_IRQ_TRIGGER, SRC3, 1, 3)
    DEP_FIELD(GICP3_IRQ_TRIGGER, SRC2, 1, 2)
    DEP_FIELD(GICP3_IRQ_TRIGGER, SRC1, 1, 1)
    DEP_FIELD(GICP3_IRQ_TRIGGER, SRC0, 1, 0)
DEP_REG32(GICP4_IRQ_STATUS, 0x50)
    DEP_FIELD(GICP4_IRQ_STATUS, SRC31, 1, 31)
    DEP_FIELD(GICP4_IRQ_STATUS, SRC30, 1, 30)
    DEP_FIELD(GICP4_IRQ_STATUS, SRC29, 1, 29)
    DEP_FIELD(GICP4_IRQ_STATUS, SRC28, 1, 28)
    DEP_FIELD(GICP4_IRQ_STATUS, SRC27, 1, 27)
    DEP_FIELD(GICP4_IRQ_STATUS, SRC26, 1, 26)
    DEP_FIELD(GICP4_IRQ_STATUS, SRC25, 1, 25)
    DEP_FIELD(GICP4_IRQ_STATUS, SRC24, 1, 24)
    DEP_FIELD(GICP4_IRQ_STATUS, SRC23, 1, 23)
    DEP_FIELD(GICP4_IRQ_STATUS, SRC22, 1, 22)
    DEP_FIELD(GICP4_IRQ_STATUS, SRC21, 1, 21)
    DEP_FIELD(GICP4_IRQ_STATUS, SRC20, 1, 20)
    DEP_FIELD(GICP4_IRQ_STATUS, SRC19, 1, 19)
    DEP_FIELD(GICP4_IRQ_STATUS, SRC18, 1, 18)
    DEP_FIELD(GICP4_IRQ_STATUS, SRC17, 1, 17)
    DEP_FIELD(GICP4_IRQ_STATUS, SRC16, 1, 16)
    DEP_FIELD(GICP4_IRQ_STATUS, SRC15, 1, 15)
    DEP_FIELD(GICP4_IRQ_STATUS, SRC14, 1, 14)
    DEP_FIELD(GICP4_IRQ_STATUS, SRC13, 1, 13)
    DEP_FIELD(GICP4_IRQ_STATUS, SRC12, 1, 12)
    DEP_FIELD(GICP4_IRQ_STATUS, SRC11, 1, 11)
    DEP_FIELD(GICP4_IRQ_STATUS, SRC10, 1, 10)
    DEP_FIELD(GICP4_IRQ_STATUS, SRC9, 1, 9)
    DEP_FIELD(GICP4_IRQ_STATUS, SRC8, 1, 8)
    DEP_FIELD(GICP4_IRQ_STATUS, SRC7, 1, 7)
    DEP_FIELD(GICP4_IRQ_STATUS, SRC6, 1, 6)
    DEP_FIELD(GICP4_IRQ_STATUS, SRC5, 1, 5)
    DEP_FIELD(GICP4_IRQ_STATUS, SRC4, 1, 4)
    DEP_FIELD(GICP4_IRQ_STATUS, SRC3, 1, 3)
    DEP_FIELD(GICP4_IRQ_STATUS, SRC2, 1, 2)
    DEP_FIELD(GICP4_IRQ_STATUS, SRC1, 1, 1)
    DEP_FIELD(GICP4_IRQ_STATUS, SRC0, 1, 0)
DEP_REG32(GICP4_IRQ_MASK, 0x54)
    DEP_FIELD(GICP4_IRQ_MASK, SRC31, 1, 31)
    DEP_FIELD(GICP4_IRQ_MASK, SRC30, 1, 30)
    DEP_FIELD(GICP4_IRQ_MASK, SRC29, 1, 29)
    DEP_FIELD(GICP4_IRQ_MASK, SRC28, 1, 28)
    DEP_FIELD(GICP4_IRQ_MASK, SRC27, 1, 27)
    DEP_FIELD(GICP4_IRQ_MASK, SRC26, 1, 26)
    DEP_FIELD(GICP4_IRQ_MASK, SRC25, 1, 25)
    DEP_FIELD(GICP4_IRQ_MASK, SRC24, 1, 24)
    DEP_FIELD(GICP4_IRQ_MASK, SRC23, 1, 23)
    DEP_FIELD(GICP4_IRQ_MASK, SRC22, 1, 22)
    DEP_FIELD(GICP4_IRQ_MASK, SRC21, 1, 21)
    DEP_FIELD(GICP4_IRQ_MASK, SRC20, 1, 20)
    DEP_FIELD(GICP4_IRQ_MASK, SRC19, 1, 19)
    DEP_FIELD(GICP4_IRQ_MASK, SRC18, 1, 18)
    DEP_FIELD(GICP4_IRQ_MASK, SRC17, 1, 17)
    DEP_FIELD(GICP4_IRQ_MASK, SRC16, 1, 16)
    DEP_FIELD(GICP4_IRQ_MASK, SRC15, 1, 15)
    DEP_FIELD(GICP4_IRQ_MASK, SRC14, 1, 14)
    DEP_FIELD(GICP4_IRQ_MASK, SRC13, 1, 13)
    DEP_FIELD(GICP4_IRQ_MASK, SRC12, 1, 12)
    DEP_FIELD(GICP4_IRQ_MASK, SRC11, 1, 11)
    DEP_FIELD(GICP4_IRQ_MASK, SRC10, 1, 10)
    DEP_FIELD(GICP4_IRQ_MASK, SRC9, 1, 9)
    DEP_FIELD(GICP4_IRQ_MASK, SRC8, 1, 8)
    DEP_FIELD(GICP4_IRQ_MASK, SRC7, 1, 7)
    DEP_FIELD(GICP4_IRQ_MASK, SRC6, 1, 6)
    DEP_FIELD(GICP4_IRQ_MASK, SRC5, 1, 5)
    DEP_FIELD(GICP4_IRQ_MASK, SRC4, 1, 4)
    DEP_FIELD(GICP4_IRQ_MASK, SRC3, 1, 3)
    DEP_FIELD(GICP4_IRQ_MASK, SRC2, 1, 2)
    DEP_FIELD(GICP4_IRQ_MASK, SRC1, 1, 1)
    DEP_FIELD(GICP4_IRQ_MASK, SRC0, 1, 0)
DEP_REG32(GICP4_IRQ_ENABLE, 0x58)
    DEP_FIELD(GICP4_IRQ_ENABLE, SRC31, 1, 31)
    DEP_FIELD(GICP4_IRQ_ENABLE, SRC30, 1, 30)
    DEP_FIELD(GICP4_IRQ_ENABLE, SRC29, 1, 29)
    DEP_FIELD(GICP4_IRQ_ENABLE, SRC28, 1, 28)
    DEP_FIELD(GICP4_IRQ_ENABLE, SRC27, 1, 27)
    DEP_FIELD(GICP4_IRQ_ENABLE, SRC26, 1, 26)
    DEP_FIELD(GICP4_IRQ_ENABLE, SRC25, 1, 25)
    DEP_FIELD(GICP4_IRQ_ENABLE, SRC24, 1, 24)
    DEP_FIELD(GICP4_IRQ_ENABLE, SRC23, 1, 23)
    DEP_FIELD(GICP4_IRQ_ENABLE, SRC22, 1, 22)
    DEP_FIELD(GICP4_IRQ_ENABLE, SRC21, 1, 21)
    DEP_FIELD(GICP4_IRQ_ENABLE, SRC20, 1, 20)
    DEP_FIELD(GICP4_IRQ_ENABLE, SRC19, 1, 19)
    DEP_FIELD(GICP4_IRQ_ENABLE, SRC18, 1, 18)
    DEP_FIELD(GICP4_IRQ_ENABLE, SRC17, 1, 17)
    DEP_FIELD(GICP4_IRQ_ENABLE, SRC16, 1, 16)
    DEP_FIELD(GICP4_IRQ_ENABLE, SRC15, 1, 15)
    DEP_FIELD(GICP4_IRQ_ENABLE, SRC14, 1, 14)
    DEP_FIELD(GICP4_IRQ_ENABLE, SRC13, 1, 13)
    DEP_FIELD(GICP4_IRQ_ENABLE, SRC12, 1, 12)
    DEP_FIELD(GICP4_IRQ_ENABLE, SRC11, 1, 11)
    DEP_FIELD(GICP4_IRQ_ENABLE, SRC10, 1, 10)
    DEP_FIELD(GICP4_IRQ_ENABLE, SRC9, 1, 9)
    DEP_FIELD(GICP4_IRQ_ENABLE, SRC8, 1, 8)
    DEP_FIELD(GICP4_IRQ_ENABLE, SRC7, 1, 7)
    DEP_FIELD(GICP4_IRQ_ENABLE, SRC6, 1, 6)
    DEP_FIELD(GICP4_IRQ_ENABLE, SRC5, 1, 5)
    DEP_FIELD(GICP4_IRQ_ENABLE, SRC4, 1, 4)
    DEP_FIELD(GICP4_IRQ_ENABLE, SRC3, 1, 3)
    DEP_FIELD(GICP4_IRQ_ENABLE, SRC2, 1, 2)
    DEP_FIELD(GICP4_IRQ_ENABLE, SRC1, 1, 1)
    DEP_FIELD(GICP4_IRQ_ENABLE, SRC0, 1, 0)
DEP_REG32(GICP4_IRQ_DISABLE, 0x5c)
    DEP_FIELD(GICP4_IRQ_DISABLE, SRC31, 1, 31)
    DEP_FIELD(GICP4_IRQ_DISABLE, SRC30, 1, 30)
    DEP_FIELD(GICP4_IRQ_DISABLE, SRC29, 1, 29)
    DEP_FIELD(GICP4_IRQ_DISABLE, SRC28, 1, 28)
    DEP_FIELD(GICP4_IRQ_DISABLE, SRC27, 1, 27)
    DEP_FIELD(GICP4_IRQ_DISABLE, SRC26, 1, 26)
    DEP_FIELD(GICP4_IRQ_DISABLE, SRC25, 1, 25)
    DEP_FIELD(GICP4_IRQ_DISABLE, SRC24, 1, 24)
    DEP_FIELD(GICP4_IRQ_DISABLE, SRC23, 1, 23)
    DEP_FIELD(GICP4_IRQ_DISABLE, SRC22, 1, 22)
    DEP_FIELD(GICP4_IRQ_DISABLE, SRC21, 1, 21)
    DEP_FIELD(GICP4_IRQ_DISABLE, SRC20, 1, 20)
    DEP_FIELD(GICP4_IRQ_DISABLE, SRC19, 1, 19)
    DEP_FIELD(GICP4_IRQ_DISABLE, SRC18, 1, 18)
    DEP_FIELD(GICP4_IRQ_DISABLE, SRC17, 1, 17)
    DEP_FIELD(GICP4_IRQ_DISABLE, SRC16, 1, 16)
    DEP_FIELD(GICP4_IRQ_DISABLE, SRC15, 1, 15)
    DEP_FIELD(GICP4_IRQ_DISABLE, SRC14, 1, 14)
    DEP_FIELD(GICP4_IRQ_DISABLE, SRC13, 1, 13)
    DEP_FIELD(GICP4_IRQ_DISABLE, SRC12, 1, 12)
    DEP_FIELD(GICP4_IRQ_DISABLE, SRC11, 1, 11)
    DEP_FIELD(GICP4_IRQ_DISABLE, SRC10, 1, 10)
    DEP_FIELD(GICP4_IRQ_DISABLE, SRC9, 1, 9)
    DEP_FIELD(GICP4_IRQ_DISABLE, SRC8, 1, 8)
    DEP_FIELD(GICP4_IRQ_DISABLE, SRC7, 1, 7)
    DEP_FIELD(GICP4_IRQ_DISABLE, SRC6, 1, 6)
    DEP_FIELD(GICP4_IRQ_DISABLE, SRC5, 1, 5)
    DEP_FIELD(GICP4_IRQ_DISABLE, SRC4, 1, 4)
    DEP_FIELD(GICP4_IRQ_DISABLE, SRC3, 1, 3)
    DEP_FIELD(GICP4_IRQ_DISABLE, SRC2, 1, 2)
    DEP_FIELD(GICP4_IRQ_DISABLE, SRC1, 1, 1)
    DEP_FIELD(GICP4_IRQ_DISABLE, SRC0, 1, 0)
DEP_REG32(GICP4_IRQ_TRIGGER, 0x60)
    DEP_FIELD(GICP4_IRQ_TRIGGER, SRC31, 1, 31)
    DEP_FIELD(GICP4_IRQ_TRIGGER, SRC30, 1, 30)
    DEP_FIELD(GICP4_IRQ_TRIGGER, SRC29, 1, 29)
    DEP_FIELD(GICP4_IRQ_TRIGGER, SRC28, 1, 28)
    DEP_FIELD(GICP4_IRQ_TRIGGER, SRC27, 1, 27)
    DEP_FIELD(GICP4_IRQ_TRIGGER, SRC26, 1, 26)
    DEP_FIELD(GICP4_IRQ_TRIGGER, SRC25, 1, 25)
    DEP_FIELD(GICP4_IRQ_TRIGGER, SRC24, 1, 24)
    DEP_FIELD(GICP4_IRQ_TRIGGER, SRC23, 1, 23)
    DEP_FIELD(GICP4_IRQ_TRIGGER, SRC22, 1, 22)
    DEP_FIELD(GICP4_IRQ_TRIGGER, SRC21, 1, 21)
    DEP_FIELD(GICP4_IRQ_TRIGGER, SRC20, 1, 20)
    DEP_FIELD(GICP4_IRQ_TRIGGER, SRC19, 1, 19)
    DEP_FIELD(GICP4_IRQ_TRIGGER, SRC18, 1, 18)
    DEP_FIELD(GICP4_IRQ_TRIGGER, SRC17, 1, 17)
    DEP_FIELD(GICP4_IRQ_TRIGGER, SRC16, 1, 16)
    DEP_FIELD(GICP4_IRQ_TRIGGER, SRC15, 1, 15)
    DEP_FIELD(GICP4_IRQ_TRIGGER, SRC14, 1, 14)
    DEP_FIELD(GICP4_IRQ_TRIGGER, SRC13, 1, 13)
    DEP_FIELD(GICP4_IRQ_TRIGGER, SRC12, 1, 12)
    DEP_FIELD(GICP4_IRQ_TRIGGER, SRC11, 1, 11)
    DEP_FIELD(GICP4_IRQ_TRIGGER, SRC10, 1, 10)
    DEP_FIELD(GICP4_IRQ_TRIGGER, SRC9, 1, 9)
    DEP_FIELD(GICP4_IRQ_TRIGGER, SRC8, 1, 8)
    DEP_FIELD(GICP4_IRQ_TRIGGER, SRC7, 1, 7)
    DEP_FIELD(GICP4_IRQ_TRIGGER, SRC6, 1, 6)
    DEP_FIELD(GICP4_IRQ_TRIGGER, SRC5, 1, 5)
    DEP_FIELD(GICP4_IRQ_TRIGGER, SRC4, 1, 4)
    DEP_FIELD(GICP4_IRQ_TRIGGER, SRC3, 1, 3)
    DEP_FIELD(GICP4_IRQ_TRIGGER, SRC2, 1, 2)
    DEP_FIELD(GICP4_IRQ_TRIGGER, SRC1, 1, 1)
    DEP_FIELD(GICP4_IRQ_TRIGGER, SRC0, 1, 0)
DEP_REG32(GICP5_IRQ_STATUS, 0x64)
    DEP_FIELD(GICP5_IRQ_STATUS, SRC31, 1, 31)
    DEP_FIELD(GICP5_IRQ_STATUS, SRC30, 1, 30)
    DEP_FIELD(GICP5_IRQ_STATUS, SRC29, 1, 29)
    DEP_FIELD(GICP5_IRQ_STATUS, SRC28, 1, 28)
    DEP_FIELD(GICP5_IRQ_STATUS, SRC27, 1, 27)
    DEP_FIELD(GICP5_IRQ_STATUS, SRC26, 1, 26)
    DEP_FIELD(GICP5_IRQ_STATUS, SRC25, 1, 25)
    DEP_FIELD(GICP5_IRQ_STATUS, SRC24, 1, 24)
    DEP_FIELD(GICP5_IRQ_STATUS, SRC23, 1, 23)
    DEP_FIELD(GICP5_IRQ_STATUS, SRC22, 1, 22)
    DEP_FIELD(GICP5_IRQ_STATUS, SRC21, 1, 21)
    DEP_FIELD(GICP5_IRQ_STATUS, SRC20, 1, 20)
    DEP_FIELD(GICP5_IRQ_STATUS, SRC19, 1, 19)
    DEP_FIELD(GICP5_IRQ_STATUS, SRC18, 1, 18)
    DEP_FIELD(GICP5_IRQ_STATUS, SRC17, 1, 17)
    DEP_FIELD(GICP5_IRQ_STATUS, SRC16, 1, 16)
    DEP_FIELD(GICP5_IRQ_STATUS, SRC15, 1, 15)
    DEP_FIELD(GICP5_IRQ_STATUS, SRC14, 1, 14)
    DEP_FIELD(GICP5_IRQ_STATUS, SRC13, 1, 13)
    DEP_FIELD(GICP5_IRQ_STATUS, SRC12, 1, 12)
    DEP_FIELD(GICP5_IRQ_STATUS, SRC11, 1, 11)
    DEP_FIELD(GICP5_IRQ_STATUS, SRC10, 1, 10)
    DEP_FIELD(GICP5_IRQ_STATUS, SRC9, 1, 9)
    DEP_FIELD(GICP5_IRQ_STATUS, SRC8, 1, 8)
    DEP_FIELD(GICP5_IRQ_STATUS, SRC7, 1, 7)
    DEP_FIELD(GICP5_IRQ_STATUS, SRC6, 1, 6)
    DEP_FIELD(GICP5_IRQ_STATUS, SRC5, 1, 5)
    DEP_FIELD(GICP5_IRQ_STATUS, SRC4, 1, 4)
    DEP_FIELD(GICP5_IRQ_STATUS, SRC3, 1, 3)
    DEP_FIELD(GICP5_IRQ_STATUS, SRC2, 1, 2)
    DEP_FIELD(GICP5_IRQ_STATUS, SRC1, 1, 1)
    DEP_FIELD(GICP5_IRQ_STATUS, SRC0, 1, 0)
DEP_REG32(GICP5_IRQ_MASK, 0x68)
    DEP_FIELD(GICP5_IRQ_MASK, SRC31, 1, 31)
    DEP_FIELD(GICP5_IRQ_MASK, SRC30, 1, 30)
    DEP_FIELD(GICP5_IRQ_MASK, SRC29, 1, 29)
    DEP_FIELD(GICP5_IRQ_MASK, SRC28, 1, 28)
    DEP_FIELD(GICP5_IRQ_MASK, SRC27, 1, 27)
    DEP_FIELD(GICP5_IRQ_MASK, SRC26, 1, 26)
    DEP_FIELD(GICP5_IRQ_MASK, SRC25, 1, 25)
    DEP_FIELD(GICP5_IRQ_MASK, SRC24, 1, 24)
    DEP_FIELD(GICP5_IRQ_MASK, SRC23, 1, 23)
    DEP_FIELD(GICP5_IRQ_MASK, SRC22, 1, 22)
    DEP_FIELD(GICP5_IRQ_MASK, SRC21, 1, 21)
    DEP_FIELD(GICP5_IRQ_MASK, SRC20, 1, 20)
    DEP_FIELD(GICP5_IRQ_MASK, SRC19, 1, 19)
    DEP_FIELD(GICP5_IRQ_MASK, SRC18, 1, 18)
    DEP_FIELD(GICP5_IRQ_MASK, SRC17, 1, 17)
    DEP_FIELD(GICP5_IRQ_MASK, SRC16, 1, 16)
    DEP_FIELD(GICP5_IRQ_MASK, SRC15, 1, 15)
    DEP_FIELD(GICP5_IRQ_MASK, SRC14, 1, 14)
    DEP_FIELD(GICP5_IRQ_MASK, SRC13, 1, 13)
    DEP_FIELD(GICP5_IRQ_MASK, SRC12, 1, 12)
    DEP_FIELD(GICP5_IRQ_MASK, SRC11, 1, 11)
    DEP_FIELD(GICP5_IRQ_MASK, SRC10, 1, 10)
    DEP_FIELD(GICP5_IRQ_MASK, SRC9, 1, 9)
    DEP_FIELD(GICP5_IRQ_MASK, SRC8, 1, 8)
    DEP_FIELD(GICP5_IRQ_MASK, SRC7, 1, 7)
    DEP_FIELD(GICP5_IRQ_MASK, SRC6, 1, 6)
    DEP_FIELD(GICP5_IRQ_MASK, SRC5, 1, 5)
    DEP_FIELD(GICP5_IRQ_MASK, SRC4, 1, 4)
    DEP_FIELD(GICP5_IRQ_MASK, SRC3, 1, 3)
    DEP_FIELD(GICP5_IRQ_MASK, SRC2, 1, 2)
    DEP_FIELD(GICP5_IRQ_MASK, SRC1, 1, 1)
    DEP_FIELD(GICP5_IRQ_MASK, SRC0, 1, 0)
DEP_REG32(GICP5_IRQ_ENABLE, 0x6c)
    DEP_FIELD(GICP5_IRQ_ENABLE, SRC31, 1, 31)
    DEP_FIELD(GICP5_IRQ_ENABLE, SRC30, 1, 30)
    DEP_FIELD(GICP5_IRQ_ENABLE, SRC29, 1, 29)
    DEP_FIELD(GICP5_IRQ_ENABLE, SRC28, 1, 28)
    DEP_FIELD(GICP5_IRQ_ENABLE, SRC27, 1, 27)
    DEP_FIELD(GICP5_IRQ_ENABLE, SRC26, 1, 26)
    DEP_FIELD(GICP5_IRQ_ENABLE, SRC25, 1, 25)
    DEP_FIELD(GICP5_IRQ_ENABLE, SRC24, 1, 24)
    DEP_FIELD(GICP5_IRQ_ENABLE, SRC23, 1, 23)
    DEP_FIELD(GICP5_IRQ_ENABLE, SRC22, 1, 22)
    DEP_FIELD(GICP5_IRQ_ENABLE, SRC21, 1, 21)
    DEP_FIELD(GICP5_IRQ_ENABLE, SRC20, 1, 20)
    DEP_FIELD(GICP5_IRQ_ENABLE, SRC19, 1, 19)
    DEP_FIELD(GICP5_IRQ_ENABLE, SRC18, 1, 18)
    DEP_FIELD(GICP5_IRQ_ENABLE, SRC17, 1, 17)
    DEP_FIELD(GICP5_IRQ_ENABLE, SRC16, 1, 16)
    DEP_FIELD(GICP5_IRQ_ENABLE, SRC15, 1, 15)
    DEP_FIELD(GICP5_IRQ_ENABLE, SRC14, 1, 14)
    DEP_FIELD(GICP5_IRQ_ENABLE, SRC13, 1, 13)
    DEP_FIELD(GICP5_IRQ_ENABLE, SRC12, 1, 12)
    DEP_FIELD(GICP5_IRQ_ENABLE, SRC11, 1, 11)
    DEP_FIELD(GICP5_IRQ_ENABLE, SRC10, 1, 10)
    DEP_FIELD(GICP5_IRQ_ENABLE, SRC9, 1, 9)
    DEP_FIELD(GICP5_IRQ_ENABLE, SRC8, 1, 8)
    DEP_FIELD(GICP5_IRQ_ENABLE, SRC7, 1, 7)
    DEP_FIELD(GICP5_IRQ_ENABLE, SRC6, 1, 6)
    DEP_FIELD(GICP5_IRQ_ENABLE, SRC5, 1, 5)
    DEP_FIELD(GICP5_IRQ_ENABLE, SRC4, 1, 4)
    DEP_FIELD(GICP5_IRQ_ENABLE, SRC3, 1, 3)
    DEP_FIELD(GICP5_IRQ_ENABLE, SRC2, 1, 2)
    DEP_FIELD(GICP5_IRQ_ENABLE, SRC1, 1, 1)
    DEP_FIELD(GICP5_IRQ_ENABLE, SRC0, 1, 0)
DEP_REG32(GICP5_IRQ_DISABLE, 0x70)
    DEP_FIELD(GICP5_IRQ_DISABLE, SRC31, 1, 31)
    DEP_FIELD(GICP5_IRQ_DISABLE, SRC30, 1, 30)
    DEP_FIELD(GICP5_IRQ_DISABLE, SRC29, 1, 29)
    DEP_FIELD(GICP5_IRQ_DISABLE, SRC28, 1, 28)
    DEP_FIELD(GICP5_IRQ_DISABLE, SRC27, 1, 27)
    DEP_FIELD(GICP5_IRQ_DISABLE, SRC26, 1, 26)
    DEP_FIELD(GICP5_IRQ_DISABLE, SRC25, 1, 25)
    DEP_FIELD(GICP5_IRQ_DISABLE, SRC24, 1, 24)
    DEP_FIELD(GICP5_IRQ_DISABLE, SRC23, 1, 23)
    DEP_FIELD(GICP5_IRQ_DISABLE, SRC22, 1, 22)
    DEP_FIELD(GICP5_IRQ_DISABLE, SRC21, 1, 21)
    DEP_FIELD(GICP5_IRQ_DISABLE, SRC20, 1, 20)
    DEP_FIELD(GICP5_IRQ_DISABLE, SRC19, 1, 19)
    DEP_FIELD(GICP5_IRQ_DISABLE, SRC18, 1, 18)
    DEP_FIELD(GICP5_IRQ_DISABLE, SRC17, 1, 17)
    DEP_FIELD(GICP5_IRQ_DISABLE, SRC16, 1, 16)
    DEP_FIELD(GICP5_IRQ_DISABLE, SRC15, 1, 15)
    DEP_FIELD(GICP5_IRQ_DISABLE, SRC14, 1, 14)
    DEP_FIELD(GICP5_IRQ_DISABLE, SRC13, 1, 13)
    DEP_FIELD(GICP5_IRQ_DISABLE, SRC12, 1, 12)
    DEP_FIELD(GICP5_IRQ_DISABLE, SRC11, 1, 11)
    DEP_FIELD(GICP5_IRQ_DISABLE, SRC10, 1, 10)
    DEP_FIELD(GICP5_IRQ_DISABLE, SRC9, 1, 9)
    DEP_FIELD(GICP5_IRQ_DISABLE, SRC8, 1, 8)
    DEP_FIELD(GICP5_IRQ_DISABLE, SRC7, 1, 7)
    DEP_FIELD(GICP5_IRQ_DISABLE, SRC6, 1, 6)
    DEP_FIELD(GICP5_IRQ_DISABLE, SRC5, 1, 5)
    DEP_FIELD(GICP5_IRQ_DISABLE, SRC4, 1, 4)
    DEP_FIELD(GICP5_IRQ_DISABLE, SRC3, 1, 3)
    DEP_FIELD(GICP5_IRQ_DISABLE, SRC2, 1, 2)
    DEP_FIELD(GICP5_IRQ_DISABLE, SRC1, 1, 1)
    DEP_FIELD(GICP5_IRQ_DISABLE, SRC0, 1, 0)
DEP_REG32(GICP5_IRQ_TRIGGER, 0x74)
    DEP_FIELD(GICP5_IRQ_TRIGGER, SRC31, 1, 31)
    DEP_FIELD(GICP5_IRQ_TRIGGER, SRC30, 1, 30)
    DEP_FIELD(GICP5_IRQ_TRIGGER, SRC29, 1, 29)
    DEP_FIELD(GICP5_IRQ_TRIGGER, SRC28, 1, 28)
    DEP_FIELD(GICP5_IRQ_TRIGGER, SRC27, 1, 27)
    DEP_FIELD(GICP5_IRQ_TRIGGER, SRC26, 1, 26)
    DEP_FIELD(GICP5_IRQ_TRIGGER, SRC25, 1, 25)
    DEP_FIELD(GICP5_IRQ_TRIGGER, SRC24, 1, 24)
    DEP_FIELD(GICP5_IRQ_TRIGGER, SRC23, 1, 23)
    DEP_FIELD(GICP5_IRQ_TRIGGER, SRC22, 1, 22)
    DEP_FIELD(GICP5_IRQ_TRIGGER, SRC21, 1, 21)
    DEP_FIELD(GICP5_IRQ_TRIGGER, SRC20, 1, 20)
    DEP_FIELD(GICP5_IRQ_TRIGGER, SRC19, 1, 19)
    DEP_FIELD(GICP5_IRQ_TRIGGER, SRC18, 1, 18)
    DEP_FIELD(GICP5_IRQ_TRIGGER, SRC17, 1, 17)
    DEP_FIELD(GICP5_IRQ_TRIGGER, SRC16, 1, 16)
    DEP_FIELD(GICP5_IRQ_TRIGGER, SRC15, 1, 15)
    DEP_FIELD(GICP5_IRQ_TRIGGER, SRC14, 1, 14)
    DEP_FIELD(GICP5_IRQ_TRIGGER, SRC13, 1, 13)
    DEP_FIELD(GICP5_IRQ_TRIGGER, SRC12, 1, 12)
    DEP_FIELD(GICP5_IRQ_TRIGGER, SRC11, 1, 11)
    DEP_FIELD(GICP5_IRQ_TRIGGER, SRC10, 1, 10)
    DEP_FIELD(GICP5_IRQ_TRIGGER, SRC9, 1, 9)
    DEP_FIELD(GICP5_IRQ_TRIGGER, SRC8, 1, 8)
    DEP_FIELD(GICP5_IRQ_TRIGGER, SRC7, 1, 7)
    DEP_FIELD(GICP5_IRQ_TRIGGER, SRC6, 1, 6)
    DEP_FIELD(GICP5_IRQ_TRIGGER, SRC5, 1, 5)
    DEP_FIELD(GICP5_IRQ_TRIGGER, SRC4, 1, 4)
    DEP_FIELD(GICP5_IRQ_TRIGGER, SRC3, 1, 3)
    DEP_FIELD(GICP5_IRQ_TRIGGER, SRC2, 1, 2)
    DEP_FIELD(GICP5_IRQ_TRIGGER, SRC1, 1, 1)
    DEP_FIELD(GICP5_IRQ_TRIGGER, SRC0, 1, 0)
DEP_REG32(GICP6_IRQ_STATUS, 0x78)
    DEP_FIELD(GICP6_IRQ_STATUS, SRC31, 1, 31)
    DEP_FIELD(GICP6_IRQ_STATUS, SRC30, 1, 30)
    DEP_FIELD(GICP6_IRQ_STATUS, SRC29, 1, 29)
    DEP_FIELD(GICP6_IRQ_STATUS, SRC28, 1, 28)
    DEP_FIELD(GICP6_IRQ_STATUS, SRC27, 1, 27)
    DEP_FIELD(GICP6_IRQ_STATUS, SRC26, 1, 26)
    DEP_FIELD(GICP6_IRQ_STATUS, SRC25, 1, 25)
    DEP_FIELD(GICP6_IRQ_STATUS, SRC24, 1, 24)
    DEP_FIELD(GICP6_IRQ_STATUS, SRC23, 1, 23)
    DEP_FIELD(GICP6_IRQ_STATUS, SRC22, 1, 22)
    DEP_FIELD(GICP6_IRQ_STATUS, SRC21, 1, 21)
    DEP_FIELD(GICP6_IRQ_STATUS, SRC20, 1, 20)
    DEP_FIELD(GICP6_IRQ_STATUS, SRC19, 1, 19)
    DEP_FIELD(GICP6_IRQ_STATUS, SRC18, 1, 18)
    DEP_FIELD(GICP6_IRQ_STATUS, SRC17, 1, 17)
    DEP_FIELD(GICP6_IRQ_STATUS, SRC16, 1, 16)
    DEP_FIELD(GICP6_IRQ_STATUS, SRC15, 1, 15)
    DEP_FIELD(GICP6_IRQ_STATUS, SRC14, 1, 14)
    DEP_FIELD(GICP6_IRQ_STATUS, SRC13, 1, 13)
    DEP_FIELD(GICP6_IRQ_STATUS, SRC12, 1, 12)
    DEP_FIELD(GICP6_IRQ_STATUS, SRC11, 1, 11)
    DEP_FIELD(GICP6_IRQ_STATUS, SRC10, 1, 10)
    DEP_FIELD(GICP6_IRQ_STATUS, SRC9, 1, 9)
    DEP_FIELD(GICP6_IRQ_STATUS, SRC8, 1, 8)
    DEP_FIELD(GICP6_IRQ_STATUS, SRC7, 1, 7)
    DEP_FIELD(GICP6_IRQ_STATUS, SRC6, 1, 6)
    DEP_FIELD(GICP6_IRQ_STATUS, SRC5, 1, 5)
    DEP_FIELD(GICP6_IRQ_STATUS, SRC4, 1, 4)
    DEP_FIELD(GICP6_IRQ_STATUS, SRC3, 1, 3)
    DEP_FIELD(GICP6_IRQ_STATUS, SRC2, 1, 2)
    DEP_FIELD(GICP6_IRQ_STATUS, SRC1, 1, 1)
    DEP_FIELD(GICP6_IRQ_STATUS, SRC0, 1, 0)
DEP_REG32(GICP6_IRQ_MASK, 0x7c)
    DEP_FIELD(GICP6_IRQ_MASK, SRC31, 1, 31)
    DEP_FIELD(GICP6_IRQ_MASK, SRC30, 1, 30)
    DEP_FIELD(GICP6_IRQ_MASK, SRC29, 1, 29)
    DEP_FIELD(GICP6_IRQ_MASK, SRC28, 1, 28)
    DEP_FIELD(GICP6_IRQ_MASK, SRC27, 1, 27)
    DEP_FIELD(GICP6_IRQ_MASK, SRC26, 1, 26)
    DEP_FIELD(GICP6_IRQ_MASK, SRC25, 1, 25)
    DEP_FIELD(GICP6_IRQ_MASK, SRC24, 1, 24)
    DEP_FIELD(GICP6_IRQ_MASK, SRC23, 1, 23)
    DEP_FIELD(GICP6_IRQ_MASK, SRC22, 1, 22)
    DEP_FIELD(GICP6_IRQ_MASK, SRC21, 1, 21)
    DEP_FIELD(GICP6_IRQ_MASK, SRC20, 1, 20)
    DEP_FIELD(GICP6_IRQ_MASK, SRC19, 1, 19)
    DEP_FIELD(GICP6_IRQ_MASK, SRC18, 1, 18)
    DEP_FIELD(GICP6_IRQ_MASK, SRC17, 1, 17)
    DEP_FIELD(GICP6_IRQ_MASK, SRC16, 1, 16)
    DEP_FIELD(GICP6_IRQ_MASK, SRC15, 1, 15)
    DEP_FIELD(GICP6_IRQ_MASK, SRC14, 1, 14)
    DEP_FIELD(GICP6_IRQ_MASK, SRC13, 1, 13)
    DEP_FIELD(GICP6_IRQ_MASK, SRC12, 1, 12)
    DEP_FIELD(GICP6_IRQ_MASK, SRC11, 1, 11)
    DEP_FIELD(GICP6_IRQ_MASK, SRC10, 1, 10)
    DEP_FIELD(GICP6_IRQ_MASK, SRC9, 1, 9)
    DEP_FIELD(GICP6_IRQ_MASK, SRC8, 1, 8)
    DEP_FIELD(GICP6_IRQ_MASK, SRC7, 1, 7)
    DEP_FIELD(GICP6_IRQ_MASK, SRC6, 1, 6)
    DEP_FIELD(GICP6_IRQ_MASK, SRC5, 1, 5)
    DEP_FIELD(GICP6_IRQ_MASK, SRC4, 1, 4)
    DEP_FIELD(GICP6_IRQ_MASK, SRC3, 1, 3)
    DEP_FIELD(GICP6_IRQ_MASK, SRC2, 1, 2)
    DEP_FIELD(GICP6_IRQ_MASK, SRC1, 1, 1)
    DEP_FIELD(GICP6_IRQ_MASK, SRC0, 1, 0)
DEP_REG32(GICP6_IRQ_ENABLE, 0x80)
    DEP_FIELD(GICP6_IRQ_ENABLE, SRC31, 1, 31)
    DEP_FIELD(GICP6_IRQ_ENABLE, SRC30, 1, 30)
    DEP_FIELD(GICP6_IRQ_ENABLE, SRC29, 1, 29)
    DEP_FIELD(GICP6_IRQ_ENABLE, SRC28, 1, 28)
    DEP_FIELD(GICP6_IRQ_ENABLE, SRC27, 1, 27)
    DEP_FIELD(GICP6_IRQ_ENABLE, SRC26, 1, 26)
    DEP_FIELD(GICP6_IRQ_ENABLE, SRC25, 1, 25)
    DEP_FIELD(GICP6_IRQ_ENABLE, SRC24, 1, 24)
    DEP_FIELD(GICP6_IRQ_ENABLE, SRC23, 1, 23)
    DEP_FIELD(GICP6_IRQ_ENABLE, SRC22, 1, 22)
    DEP_FIELD(GICP6_IRQ_ENABLE, SRC21, 1, 21)
    DEP_FIELD(GICP6_IRQ_ENABLE, SRC20, 1, 20)
    DEP_FIELD(GICP6_IRQ_ENABLE, SRC19, 1, 19)
    DEP_FIELD(GICP6_IRQ_ENABLE, SRC18, 1, 18)
    DEP_FIELD(GICP6_IRQ_ENABLE, SRC17, 1, 17)
    DEP_FIELD(GICP6_IRQ_ENABLE, SRC16, 1, 16)
    DEP_FIELD(GICP6_IRQ_ENABLE, SRC15, 1, 15)
    DEP_FIELD(GICP6_IRQ_ENABLE, SRC14, 1, 14)
    DEP_FIELD(GICP6_IRQ_ENABLE, SRC13, 1, 13)
    DEP_FIELD(GICP6_IRQ_ENABLE, SRC12, 1, 12)
    DEP_FIELD(GICP6_IRQ_ENABLE, SRC11, 1, 11)
    DEP_FIELD(GICP6_IRQ_ENABLE, SRC10, 1, 10)
    DEP_FIELD(GICP6_IRQ_ENABLE, SRC9, 1, 9)
    DEP_FIELD(GICP6_IRQ_ENABLE, SRC8, 1, 8)
    DEP_FIELD(GICP6_IRQ_ENABLE, SRC7, 1, 7)
    DEP_FIELD(GICP6_IRQ_ENABLE, SRC6, 1, 6)
    DEP_FIELD(GICP6_IRQ_ENABLE, SRC5, 1, 5)
    DEP_FIELD(GICP6_IRQ_ENABLE, SRC4, 1, 4)
    DEP_FIELD(GICP6_IRQ_ENABLE, SRC3, 1, 3)
    DEP_FIELD(GICP6_IRQ_ENABLE, SRC2, 1, 2)
    DEP_FIELD(GICP6_IRQ_ENABLE, SRC1, 1, 1)
    DEP_FIELD(GICP6_IRQ_ENABLE, SRC0, 1, 0)
DEP_REG32(GICP6_IRQ_DISABLE, 0x84)
    DEP_FIELD(GICP6_IRQ_DISABLE, SRC31, 1, 31)
    DEP_FIELD(GICP6_IRQ_DISABLE, SRC30, 1, 30)
    DEP_FIELD(GICP6_IRQ_DISABLE, SRC29, 1, 29)
    DEP_FIELD(GICP6_IRQ_DISABLE, SRC28, 1, 28)
    DEP_FIELD(GICP6_IRQ_DISABLE, SRC27, 1, 27)
    DEP_FIELD(GICP6_IRQ_DISABLE, SRC26, 1, 26)
    DEP_FIELD(GICP6_IRQ_DISABLE, SRC25, 1, 25)
    DEP_FIELD(GICP6_IRQ_DISABLE, SRC24, 1, 24)
    DEP_FIELD(GICP6_IRQ_DISABLE, SRC23, 1, 23)
    DEP_FIELD(GICP6_IRQ_DISABLE, SRC22, 1, 22)
    DEP_FIELD(GICP6_IRQ_DISABLE, SRC21, 1, 21)
    DEP_FIELD(GICP6_IRQ_DISABLE, SRC20, 1, 20)
    DEP_FIELD(GICP6_IRQ_DISABLE, SRC19, 1, 19)
    DEP_FIELD(GICP6_IRQ_DISABLE, SRC18, 1, 18)
    DEP_FIELD(GICP6_IRQ_DISABLE, SRC17, 1, 17)
    DEP_FIELD(GICP6_IRQ_DISABLE, SRC16, 1, 16)
    DEP_FIELD(GICP6_IRQ_DISABLE, SRC15, 1, 15)
    DEP_FIELD(GICP6_IRQ_DISABLE, SRC14, 1, 14)
    DEP_FIELD(GICP6_IRQ_DISABLE, SRC13, 1, 13)
    DEP_FIELD(GICP6_IRQ_DISABLE, SRC12, 1, 12)
    DEP_FIELD(GICP6_IRQ_DISABLE, SRC11, 1, 11)
    DEP_FIELD(GICP6_IRQ_DISABLE, SRC10, 1, 10)
    DEP_FIELD(GICP6_IRQ_DISABLE, SRC9, 1, 9)
    DEP_FIELD(GICP6_IRQ_DISABLE, SRC8, 1, 8)
    DEP_FIELD(GICP6_IRQ_DISABLE, SRC7, 1, 7)
    DEP_FIELD(GICP6_IRQ_DISABLE, SRC6, 1, 6)
    DEP_FIELD(GICP6_IRQ_DISABLE, SRC5, 1, 5)
    DEP_FIELD(GICP6_IRQ_DISABLE, SRC4, 1, 4)
    DEP_FIELD(GICP6_IRQ_DISABLE, SRC3, 1, 3)
    DEP_FIELD(GICP6_IRQ_DISABLE, SRC2, 1, 2)
    DEP_FIELD(GICP6_IRQ_DISABLE, SRC1, 1, 1)
    DEP_FIELD(GICP6_IRQ_DISABLE, SRC0, 1, 0)
DEP_REG32(GICP6_IRQ_TRIGGER, 0x88)
    DEP_FIELD(GICP6_IRQ_TRIGGER, SRC31, 1, 31)
    DEP_FIELD(GICP6_IRQ_TRIGGER, SRC30, 1, 30)
    DEP_FIELD(GICP6_IRQ_TRIGGER, SRC29, 1, 29)
    DEP_FIELD(GICP6_IRQ_TRIGGER, SRC28, 1, 28)
    DEP_FIELD(GICP6_IRQ_TRIGGER, SRC27, 1, 27)
    DEP_FIELD(GICP6_IRQ_TRIGGER, SRC26, 1, 26)
    DEP_FIELD(GICP6_IRQ_TRIGGER, SRC25, 1, 25)
    DEP_FIELD(GICP6_IRQ_TRIGGER, SRC24, 1, 24)
    DEP_FIELD(GICP6_IRQ_TRIGGER, SRC23, 1, 23)
    DEP_FIELD(GICP6_IRQ_TRIGGER, SRC22, 1, 22)
    DEP_FIELD(GICP6_IRQ_TRIGGER, SRC21, 1, 21)
    DEP_FIELD(GICP6_IRQ_TRIGGER, SRC20, 1, 20)
    DEP_FIELD(GICP6_IRQ_TRIGGER, SRC19, 1, 19)
    DEP_FIELD(GICP6_IRQ_TRIGGER, SRC18, 1, 18)
    DEP_FIELD(GICP6_IRQ_TRIGGER, SRC17, 1, 17)
    DEP_FIELD(GICP6_IRQ_TRIGGER, SRC16, 1, 16)
    DEP_FIELD(GICP6_IRQ_TRIGGER, SRC15, 1, 15)
    DEP_FIELD(GICP6_IRQ_TRIGGER, SRC14, 1, 14)
    DEP_FIELD(GICP6_IRQ_TRIGGER, SRC13, 1, 13)
    DEP_FIELD(GICP6_IRQ_TRIGGER, SRC12, 1, 12)
    DEP_FIELD(GICP6_IRQ_TRIGGER, SRC11, 1, 11)
    DEP_FIELD(GICP6_IRQ_TRIGGER, SRC10, 1, 10)
    DEP_FIELD(GICP6_IRQ_TRIGGER, SRC9, 1, 9)
    DEP_FIELD(GICP6_IRQ_TRIGGER, SRC8, 1, 8)
    DEP_FIELD(GICP6_IRQ_TRIGGER, SRC7, 1, 7)
    DEP_FIELD(GICP6_IRQ_TRIGGER, SRC6, 1, 6)
    DEP_FIELD(GICP6_IRQ_TRIGGER, SRC5, 1, 5)
    DEP_FIELD(GICP6_IRQ_TRIGGER, SRC4, 1, 4)
    DEP_FIELD(GICP6_IRQ_TRIGGER, SRC3, 1, 3)
    DEP_FIELD(GICP6_IRQ_TRIGGER, SRC2, 1, 2)
    DEP_FIELD(GICP6_IRQ_TRIGGER, SRC1, 1, 1)
    DEP_FIELD(GICP6_IRQ_TRIGGER, SRC0, 1, 0)
DEP_REG32(GICP7_IRQ_STATUS, 0x8c)
    DEP_FIELD(GICP7_IRQ_STATUS, SRC31, 1, 31)
    DEP_FIELD(GICP7_IRQ_STATUS, SRC30, 1, 30)
    DEP_FIELD(GICP7_IRQ_STATUS, SRC29, 1, 29)
    DEP_FIELD(GICP7_IRQ_STATUS, SRC28, 1, 28)
    DEP_FIELD(GICP7_IRQ_STATUS, SRC27, 1, 27)
    DEP_FIELD(GICP7_IRQ_STATUS, SRC26, 1, 26)
    DEP_FIELD(GICP7_IRQ_STATUS, SRC25, 1, 25)
    DEP_FIELD(GICP7_IRQ_STATUS, SRC24, 1, 24)
    DEP_FIELD(GICP7_IRQ_STATUS, SRC23, 1, 23)
    DEP_FIELD(GICP7_IRQ_STATUS, SRC22, 1, 22)
    DEP_FIELD(GICP7_IRQ_STATUS, SRC21, 1, 21)
    DEP_FIELD(GICP7_IRQ_STATUS, SRC20, 1, 20)
    DEP_FIELD(GICP7_IRQ_STATUS, SRC19, 1, 19)
    DEP_FIELD(GICP7_IRQ_STATUS, SRC18, 1, 18)
    DEP_FIELD(GICP7_IRQ_STATUS, SRC17, 1, 17)
    DEP_FIELD(GICP7_IRQ_STATUS, SRC16, 1, 16)
    DEP_FIELD(GICP7_IRQ_STATUS, SRC15, 1, 15)
    DEP_FIELD(GICP7_IRQ_STATUS, SRC14, 1, 14)
    DEP_FIELD(GICP7_IRQ_STATUS, SRC13, 1, 13)
    DEP_FIELD(GICP7_IRQ_STATUS, SRC12, 1, 12)
    DEP_FIELD(GICP7_IRQ_STATUS, SRC11, 1, 11)
    DEP_FIELD(GICP7_IRQ_STATUS, SRC10, 1, 10)
    DEP_FIELD(GICP7_IRQ_STATUS, SRC9, 1, 9)
    DEP_FIELD(GICP7_IRQ_STATUS, SRC8, 1, 8)
    DEP_FIELD(GICP7_IRQ_STATUS, SRC7, 1, 7)
    DEP_FIELD(GICP7_IRQ_STATUS, SRC6, 1, 6)
    DEP_FIELD(GICP7_IRQ_STATUS, SRC5, 1, 5)
    DEP_FIELD(GICP7_IRQ_STATUS, SRC4, 1, 4)
    DEP_FIELD(GICP7_IRQ_STATUS, SRC3, 1, 3)
    DEP_FIELD(GICP7_IRQ_STATUS, SRC2, 1, 2)
    DEP_FIELD(GICP7_IRQ_STATUS, SRC1, 1, 1)
    DEP_FIELD(GICP7_IRQ_STATUS, SRC0, 1, 0)
DEP_REG32(GICP7_IRQ_MASK, 0x90)
    DEP_FIELD(GICP7_IRQ_MASK, SRC31, 1, 31)
    DEP_FIELD(GICP7_IRQ_MASK, SRC30, 1, 30)
    DEP_FIELD(GICP7_IRQ_MASK, SRC29, 1, 29)
    DEP_FIELD(GICP7_IRQ_MASK, SRC28, 1, 28)
    DEP_FIELD(GICP7_IRQ_MASK, SRC27, 1, 27)
    DEP_FIELD(GICP7_IRQ_MASK, SRC26, 1, 26)
    DEP_FIELD(GICP7_IRQ_MASK, SRC25, 1, 25)
    DEP_FIELD(GICP7_IRQ_MASK, SRC24, 1, 24)
    DEP_FIELD(GICP7_IRQ_MASK, SRC23, 1, 23)
    DEP_FIELD(GICP7_IRQ_MASK, SRC22, 1, 22)
    DEP_FIELD(GICP7_IRQ_MASK, SRC21, 1, 21)
    DEP_FIELD(GICP7_IRQ_MASK, SRC20, 1, 20)
    DEP_FIELD(GICP7_IRQ_MASK, SRC19, 1, 19)
    DEP_FIELD(GICP7_IRQ_MASK, SRC18, 1, 18)
    DEP_FIELD(GICP7_IRQ_MASK, SRC17, 1, 17)
    DEP_FIELD(GICP7_IRQ_MASK, SRC16, 1, 16)
    DEP_FIELD(GICP7_IRQ_MASK, SRC15, 1, 15)
    DEP_FIELD(GICP7_IRQ_MASK, SRC14, 1, 14)
    DEP_FIELD(GICP7_IRQ_MASK, SRC13, 1, 13)
    DEP_FIELD(GICP7_IRQ_MASK, SRC12, 1, 12)
    DEP_FIELD(GICP7_IRQ_MASK, SRC11, 1, 11)
    DEP_FIELD(GICP7_IRQ_MASK, SRC10, 1, 10)
    DEP_FIELD(GICP7_IRQ_MASK, SRC9, 1, 9)
    DEP_FIELD(GICP7_IRQ_MASK, SRC8, 1, 8)
    DEP_FIELD(GICP7_IRQ_MASK, SRC7, 1, 7)
    DEP_FIELD(GICP7_IRQ_MASK, SRC6, 1, 6)
    DEP_FIELD(GICP7_IRQ_MASK, SRC5, 1, 5)
    DEP_FIELD(GICP7_IRQ_MASK, SRC4, 1, 4)
    DEP_FIELD(GICP7_IRQ_MASK, SRC3, 1, 3)
    DEP_FIELD(GICP7_IRQ_MASK, SRC2, 1, 2)
    DEP_FIELD(GICP7_IRQ_MASK, SRC1, 1, 1)
    DEP_FIELD(GICP7_IRQ_MASK, SRC0, 1, 0)
DEP_REG32(GICP7_IRQ_ENABLE, 0x94)
    DEP_FIELD(GICP7_IRQ_ENABLE, SRC31, 1, 31)
    DEP_FIELD(GICP7_IRQ_ENABLE, SRC30, 1, 30)
    DEP_FIELD(GICP7_IRQ_ENABLE, SRC29, 1, 29)
    DEP_FIELD(GICP7_IRQ_ENABLE, SRC28, 1, 28)
    DEP_FIELD(GICP7_IRQ_ENABLE, SRC27, 1, 27)
    DEP_FIELD(GICP7_IRQ_ENABLE, SRC26, 1, 26)
    DEP_FIELD(GICP7_IRQ_ENABLE, SRC25, 1, 25)
    DEP_FIELD(GICP7_IRQ_ENABLE, SRC24, 1, 24)
    DEP_FIELD(GICP7_IRQ_ENABLE, SRC23, 1, 23)
    DEP_FIELD(GICP7_IRQ_ENABLE, SRC22, 1, 22)
    DEP_FIELD(GICP7_IRQ_ENABLE, SRC21, 1, 21)
    DEP_FIELD(GICP7_IRQ_ENABLE, SRC20, 1, 20)
    DEP_FIELD(GICP7_IRQ_ENABLE, SRC19, 1, 19)
    DEP_FIELD(GICP7_IRQ_ENABLE, SRC18, 1, 18)
    DEP_FIELD(GICP7_IRQ_ENABLE, SRC17, 1, 17)
    DEP_FIELD(GICP7_IRQ_ENABLE, SRC16, 1, 16)
    DEP_FIELD(GICP7_IRQ_ENABLE, SRC15, 1, 15)
    DEP_FIELD(GICP7_IRQ_ENABLE, SRC14, 1, 14)
    DEP_FIELD(GICP7_IRQ_ENABLE, SRC13, 1, 13)
    DEP_FIELD(GICP7_IRQ_ENABLE, SRC12, 1, 12)
    DEP_FIELD(GICP7_IRQ_ENABLE, SRC11, 1, 11)
    DEP_FIELD(GICP7_IRQ_ENABLE, SRC10, 1, 10)
    DEP_FIELD(GICP7_IRQ_ENABLE, SRC9, 1, 9)
    DEP_FIELD(GICP7_IRQ_ENABLE, SRC8, 1, 8)
    DEP_FIELD(GICP7_IRQ_ENABLE, SRC7, 1, 7)
    DEP_FIELD(GICP7_IRQ_ENABLE, SRC6, 1, 6)
    DEP_FIELD(GICP7_IRQ_ENABLE, SRC5, 1, 5)
    DEP_FIELD(GICP7_IRQ_ENABLE, SRC4, 1, 4)
    DEP_FIELD(GICP7_IRQ_ENABLE, SRC3, 1, 3)
    DEP_FIELD(GICP7_IRQ_ENABLE, SRC2, 1, 2)
    DEP_FIELD(GICP7_IRQ_ENABLE, SRC1, 1, 1)
    DEP_FIELD(GICP7_IRQ_ENABLE, SRC0, 1, 0)
DEP_REG32(GICP7_IRQ_DISABLE, 0x98)
    DEP_FIELD(GICP7_IRQ_DISABLE, SRC31, 1, 31)
    DEP_FIELD(GICP7_IRQ_DISABLE, SRC30, 1, 30)
    DEP_FIELD(GICP7_IRQ_DISABLE, SRC29, 1, 29)
    DEP_FIELD(GICP7_IRQ_DISABLE, SRC28, 1, 28)
    DEP_FIELD(GICP7_IRQ_DISABLE, SRC27, 1, 27)
    DEP_FIELD(GICP7_IRQ_DISABLE, SRC26, 1, 26)
    DEP_FIELD(GICP7_IRQ_DISABLE, SRC25, 1, 25)
    DEP_FIELD(GICP7_IRQ_DISABLE, SRC24, 1, 24)
    DEP_FIELD(GICP7_IRQ_DISABLE, SRC23, 1, 23)
    DEP_FIELD(GICP7_IRQ_DISABLE, SRC22, 1, 22)
    DEP_FIELD(GICP7_IRQ_DISABLE, SRC21, 1, 21)
    DEP_FIELD(GICP7_IRQ_DISABLE, SRC20, 1, 20)
    DEP_FIELD(GICP7_IRQ_DISABLE, SRC19, 1, 19)
    DEP_FIELD(GICP7_IRQ_DISABLE, SRC18, 1, 18)
    DEP_FIELD(GICP7_IRQ_DISABLE, SRC17, 1, 17)
    DEP_FIELD(GICP7_IRQ_DISABLE, SRC16, 1, 16)
    DEP_FIELD(GICP7_IRQ_DISABLE, SRC15, 1, 15)
    DEP_FIELD(GICP7_IRQ_DISABLE, SRC14, 1, 14)
    DEP_FIELD(GICP7_IRQ_DISABLE, SRC13, 1, 13)
    DEP_FIELD(GICP7_IRQ_DISABLE, SRC12, 1, 12)
    DEP_FIELD(GICP7_IRQ_DISABLE, SRC11, 1, 11)
    DEP_FIELD(GICP7_IRQ_DISABLE, SRC10, 1, 10)
    DEP_FIELD(GICP7_IRQ_DISABLE, SRC9, 1, 9)
    DEP_FIELD(GICP7_IRQ_DISABLE, SRC8, 1, 8)
    DEP_FIELD(GICP7_IRQ_DISABLE, SRC7, 1, 7)
    DEP_FIELD(GICP7_IRQ_DISABLE, SRC6, 1, 6)
    DEP_FIELD(GICP7_IRQ_DISABLE, SRC5, 1, 5)
    DEP_FIELD(GICP7_IRQ_DISABLE, SRC4, 1, 4)
    DEP_FIELD(GICP7_IRQ_DISABLE, SRC3, 1, 3)
    DEP_FIELD(GICP7_IRQ_DISABLE, SRC2, 1, 2)
    DEP_FIELD(GICP7_IRQ_DISABLE, SRC1, 1, 1)
    DEP_FIELD(GICP7_IRQ_DISABLE, SRC0, 1, 0)
DEP_REG32(GICP7_IRQ_TRIGGER, 0x9c)
    DEP_FIELD(GICP7_IRQ_TRIGGER, SRC31, 1, 31)
    DEP_FIELD(GICP7_IRQ_TRIGGER, SRC30, 1, 30)
    DEP_FIELD(GICP7_IRQ_TRIGGER, SRC29, 1, 29)
    DEP_FIELD(GICP7_IRQ_TRIGGER, SRC28, 1, 28)
    DEP_FIELD(GICP7_IRQ_TRIGGER, SRC27, 1, 27)
    DEP_FIELD(GICP7_IRQ_TRIGGER, SRC26, 1, 26)
    DEP_FIELD(GICP7_IRQ_TRIGGER, SRC25, 1, 25)
    DEP_FIELD(GICP7_IRQ_TRIGGER, SRC24, 1, 24)
    DEP_FIELD(GICP7_IRQ_TRIGGER, SRC23, 1, 23)
    DEP_FIELD(GICP7_IRQ_TRIGGER, SRC22, 1, 22)
    DEP_FIELD(GICP7_IRQ_TRIGGER, SRC21, 1, 21)
    DEP_FIELD(GICP7_IRQ_TRIGGER, SRC20, 1, 20)
    DEP_FIELD(GICP7_IRQ_TRIGGER, SRC19, 1, 19)
    DEP_FIELD(GICP7_IRQ_TRIGGER, SRC18, 1, 18)
    DEP_FIELD(GICP7_IRQ_TRIGGER, SRC17, 1, 17)
    DEP_FIELD(GICP7_IRQ_TRIGGER, SRC16, 1, 16)
    DEP_FIELD(GICP7_IRQ_TRIGGER, SRC15, 1, 15)
    DEP_FIELD(GICP7_IRQ_TRIGGER, SRC14, 1, 14)
    DEP_FIELD(GICP7_IRQ_TRIGGER, SRC13, 1, 13)
    DEP_FIELD(GICP7_IRQ_TRIGGER, SRC12, 1, 12)
    DEP_FIELD(GICP7_IRQ_TRIGGER, SRC11, 1, 11)
    DEP_FIELD(GICP7_IRQ_TRIGGER, SRC10, 1, 10)
    DEP_FIELD(GICP7_IRQ_TRIGGER, SRC9, 1, 9)
    DEP_FIELD(GICP7_IRQ_TRIGGER, SRC8, 1, 8)
    DEP_FIELD(GICP7_IRQ_TRIGGER, SRC7, 1, 7)
    DEP_FIELD(GICP7_IRQ_TRIGGER, SRC6, 1, 6)
    DEP_FIELD(GICP7_IRQ_TRIGGER, SRC5, 1, 5)
    DEP_FIELD(GICP7_IRQ_TRIGGER, SRC4, 1, 4)
    DEP_FIELD(GICP7_IRQ_TRIGGER, SRC3, 1, 3)
    DEP_FIELD(GICP7_IRQ_TRIGGER, SRC2, 1, 2)
    DEP_FIELD(GICP7_IRQ_TRIGGER, SRC1, 1, 1)
    DEP_FIELD(GICP7_IRQ_TRIGGER, SRC0, 1, 0)
DEP_REG32(GICP_PMC_IRQ_STATUS, 0xa0)
    DEP_FIELD(GICP_PMC_IRQ_STATUS, SRC7, 1, 7)
    DEP_FIELD(GICP_PMC_IRQ_STATUS, SRC6, 1, 6)
    DEP_FIELD(GICP_PMC_IRQ_STATUS, SRC5, 1, 5)
    DEP_FIELD(GICP_PMC_IRQ_STATUS, SRC4, 1, 4)
    DEP_FIELD(GICP_PMC_IRQ_STATUS, SRC3, 1, 3)
    DEP_FIELD(GICP_PMC_IRQ_STATUS, SRC2, 1, 2)
    DEP_FIELD(GICP_PMC_IRQ_STATUS, SRC1, 1, 1)
    DEP_FIELD(GICP_PMC_IRQ_STATUS, SRC0, 1, 0)
DEP_REG32(GICP_PMC_IRQ_MASK, 0xa4)
    DEP_FIELD(GICP_PMC_IRQ_MASK, SRC7, 1, 7)
    DEP_FIELD(GICP_PMC_IRQ_MASK, SRC6, 1, 6)
    DEP_FIELD(GICP_PMC_IRQ_MASK, SRC5, 1, 5)
    DEP_FIELD(GICP_PMC_IRQ_MASK, SRC4, 1, 4)
    DEP_FIELD(GICP_PMC_IRQ_MASK, SRC3, 1, 3)
    DEP_FIELD(GICP_PMC_IRQ_MASK, SRC2, 1, 2)
    DEP_FIELD(GICP_PMC_IRQ_MASK, SRC1, 1, 1)
    DEP_FIELD(GICP_PMC_IRQ_MASK, SRC0, 1, 0)
DEP_REG32(GICP_PMC_IRQ_ENABLE, 0xa8)
    DEP_FIELD(GICP_PMC_IRQ_ENABLE, SRC7, 1, 7)
    DEP_FIELD(GICP_PMC_IRQ_ENABLE, SRC6, 1, 6)
    DEP_FIELD(GICP_PMC_IRQ_ENABLE, SRC5, 1, 5)
    DEP_FIELD(GICP_PMC_IRQ_ENABLE, SRC4, 1, 4)
    DEP_FIELD(GICP_PMC_IRQ_ENABLE, SRC3, 1, 3)
    DEP_FIELD(GICP_PMC_IRQ_ENABLE, SRC2, 1, 2)
    DEP_FIELD(GICP_PMC_IRQ_ENABLE, SRC1, 1, 1)
    DEP_FIELD(GICP_PMC_IRQ_ENABLE, SRC0, 1, 0)
DEP_REG32(GICP_PMC_IRQ_DISABLE, 0xac)
    DEP_FIELD(GICP_PMC_IRQ_DISABLE, SRC7, 1, 7)
    DEP_FIELD(GICP_PMC_IRQ_DISABLE, SRC6, 1, 6)
    DEP_FIELD(GICP_PMC_IRQ_DISABLE, SRC5, 1, 5)
    DEP_FIELD(GICP_PMC_IRQ_DISABLE, SRC4, 1, 4)
    DEP_FIELD(GICP_PMC_IRQ_DISABLE, SRC3, 1, 3)
    DEP_FIELD(GICP_PMC_IRQ_DISABLE, SRC2, 1, 2)
    DEP_FIELD(GICP_PMC_IRQ_DISABLE, SRC1, 1, 1)
    DEP_FIELD(GICP_PMC_IRQ_DISABLE, SRC0, 1, 0)
DEP_REG32(GICP_PMC_IRQ_TRIGGER, 0xb0)
    DEP_FIELD(GICP_PMC_IRQ_TRIGGER, SRC7, 1, 7)
    DEP_FIELD(GICP_PMC_IRQ_TRIGGER, SRC6, 1, 6)
    DEP_FIELD(GICP_PMC_IRQ_TRIGGER, SRC5, 1, 5)
    DEP_FIELD(GICP_PMC_IRQ_TRIGGER, SRC4, 1, 4)
    DEP_FIELD(GICP_PMC_IRQ_TRIGGER, SRC3, 1, 3)
    DEP_FIELD(GICP_PMC_IRQ_TRIGGER, SRC2, 1, 2)
    DEP_FIELD(GICP_PMC_IRQ_TRIGGER, SRC1, 1, 1)
    DEP_FIELD(GICP_PMC_IRQ_TRIGGER, SRC0, 1, 0)

#define R_MAX (R_GICP_PMC_IRQ_TRIGGER + 1)

typedef struct PMCGICProxy {
    SysBusDevice parent_obj;
    MemoryRegion iomem;

    qemu_irq irq_gicp_pmc_irq;
    qemu_irq irq_gicp0_irq;
    qemu_irq irq_gicp1_irq;
    qemu_irq irq_gicp2_irq;
    qemu_irq irq_gicp3_irq;
    qemu_irq irq_gicp4_irq;
    qemu_irq irq_gicp5_irq;
    qemu_irq irq_gicp6_irq;
    qemu_irq irq_gicp7_irq;

    uint32_t regs[R_MAX];
    DepRegisterInfo regs_info[R_MAX];
} PMCGICProxy;

static void gicp_pmc_irq_update_irq(PMCGICProxy *s)
{
    bool pending;

    pending = s->regs[R_GICP_PMC_IRQ_STATUS] & ~s->regs[R_GICP_PMC_IRQ_MASK];
    qemu_set_irq(s->irq_gicp_pmc_irq, pending);
}

static void gicp_pmc_irq_status_postw(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    gicp_pmc_irq_update_irq(s);
}

static uint64_t gicp_pmc_irq_enable_prew(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    uint32_t val = val64;

    s->regs[R_GICP_PMC_IRQ_MASK] &= ~val;
    gicp_pmc_irq_update_irq(s);
    return 0;
}

static uint64_t gicp_pmc_irq_disable_prew(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    uint32_t val = val64;

    s->regs[R_GICP_PMC_IRQ_MASK] |= val;
    gicp_pmc_irq_update_irq(s);
    return 0;
}

static uint64_t gicp_pmc_irq_trigger_prew(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    uint32_t val = val64;

    s->regs[R_GICP_PMC_IRQ_STATUS] |= val;
    gicp_pmc_irq_update_irq(s);
    return 0;
}

static void gicp0_irq_update_irq(PMCGICProxy *s)
{
    bool pending = s->regs[R_GICP0_IRQ_STATUS] & ~s->regs[R_GICP0_IRQ_MASK];
    qemu_set_irq(s->irq_gicp0_irq, pending);
    s->regs[R_GICP_PMC_IRQ_STATUS] |= pending << 0;
    gicp_pmc_irq_update_irq(s);
}

static void gicp0_irq_status_postw(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    gicp0_irq_update_irq(s);
}

static uint64_t gicp0_irq_enable_prew(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    uint32_t val = val64;

    s->regs[R_GICP0_IRQ_MASK] &= ~val;
    gicp0_irq_update_irq(s);
    return 0;
}

static uint64_t gicp0_irq_disable_prew(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    uint32_t val = val64;

    s->regs[R_GICP0_IRQ_MASK] |= val;
    gicp0_irq_update_irq(s);
    return 0;
}

static uint64_t gicp0_irq_trigger_prew(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    uint32_t val = val64;

    s->regs[R_GICP0_IRQ_STATUS] |= val;
    gicp0_irq_update_irq(s);
    return 0;
}

static void gicp1_irq_update_irq(PMCGICProxy *s)
{
    bool pending = s->regs[R_GICP1_IRQ_STATUS] & ~s->regs[R_GICP1_IRQ_MASK];
    qemu_set_irq(s->irq_gicp1_irq, pending);
    s->regs[R_GICP_PMC_IRQ_STATUS] |= pending << 1;
    gicp_pmc_irq_update_irq(s);
}

static void gicp1_irq_status_postw(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    gicp1_irq_update_irq(s);
}

static uint64_t gicp1_irq_enable_prew(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    uint32_t val = val64;

    s->regs[R_GICP1_IRQ_MASK] &= ~val;
    gicp1_irq_update_irq(s);
    return 0;
}

static uint64_t gicp1_irq_disable_prew(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    uint32_t val = val64;

    s->regs[R_GICP1_IRQ_MASK] |= val;
    gicp1_irq_update_irq(s);
    return 0;
}

static uint64_t gicp1_irq_trigger_prew(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    uint32_t val = val64;

    s->regs[R_GICP1_IRQ_STATUS] |= val;
    gicp1_irq_update_irq(s);
    return 0;
}

static void gicp2_irq_update_irq(PMCGICProxy *s)
{
    bool pending = s->regs[R_GICP2_IRQ_STATUS] & ~s->regs[R_GICP2_IRQ_MASK];
    qemu_set_irq(s->irq_gicp2_irq, pending);
    s->regs[R_GICP_PMC_IRQ_STATUS] |= pending << 2;
    gicp_pmc_irq_update_irq(s);
}

static void gicp2_irq_status_postw(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    gicp2_irq_update_irq(s);
}

static uint64_t gicp2_irq_enable_prew(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    uint32_t val = val64;

    s->regs[R_GICP2_IRQ_MASK] &= ~val;
    gicp2_irq_update_irq(s);
    return 0;
}

static uint64_t gicp2_irq_disable_prew(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    uint32_t val = val64;

    s->regs[R_GICP2_IRQ_MASK] |= val;
    gicp2_irq_update_irq(s);
    return 0;
}

static uint64_t gicp2_irq_trigger_prew(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    uint32_t val = val64;

    s->regs[R_GICP2_IRQ_STATUS] |= val;
    gicp2_irq_update_irq(s);
    return 0;
}

static void gicp3_irq_update_irq(PMCGICProxy *s)
{
    bool pending = s->regs[R_GICP3_IRQ_STATUS] & ~s->regs[R_GICP3_IRQ_MASK];
    qemu_set_irq(s->irq_gicp3_irq, pending);
    s->regs[R_GICP_PMC_IRQ_STATUS] |= pending << 3;
    gicp_pmc_irq_update_irq(s);
}

static void gicp3_irq_status_postw(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    gicp3_irq_update_irq(s);
}

static uint64_t gicp3_irq_enable_prew(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    uint32_t val = val64;

    s->regs[R_GICP3_IRQ_MASK] &= ~val;
    gicp3_irq_update_irq(s);
    return 0;
}

static uint64_t gicp3_irq_disable_prew(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    uint32_t val = val64;

    s->regs[R_GICP3_IRQ_MASK] |= val;
    gicp3_irq_update_irq(s);
    return 0;
}

static uint64_t gicp3_irq_trigger_prew(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    uint32_t val = val64;

    s->regs[R_GICP3_IRQ_STATUS] |= val;
    gicp3_irq_update_irq(s);
    return 0;
}

static void gicp4_irq_update_irq(PMCGICProxy *s)
{
    bool pending = s->regs[R_GICP4_IRQ_STATUS] & ~s->regs[R_GICP4_IRQ_MASK];
    qemu_set_irq(s->irq_gicp4_irq, pending);
    s->regs[R_GICP_PMC_IRQ_STATUS] |= pending << 4;
    gicp_pmc_irq_update_irq(s);
}

static void gicp4_irq_status_postw(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    gicp4_irq_update_irq(s);
}

static uint64_t gicp4_irq_enable_prew(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    uint32_t val = val64;

    s->regs[R_GICP4_IRQ_MASK] &= ~val;
    gicp4_irq_update_irq(s);
    return 0;
}

static uint64_t gicp4_irq_disable_prew(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    uint32_t val = val64;

    s->regs[R_GICP4_IRQ_MASK] |= val;
    gicp4_irq_update_irq(s);
    return 0;
}

static uint64_t gicp4_irq_trigger_prew(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    uint32_t val = val64;

    s->regs[R_GICP4_IRQ_STATUS] |= val;
    gicp4_irq_update_irq(s);
    return 0;
}

static void gicp5_irq_update_irq(PMCGICProxy *s)
{
    bool pending = s->regs[R_GICP5_IRQ_STATUS] & ~s->regs[R_GICP5_IRQ_MASK];
    qemu_set_irq(s->irq_gicp5_irq, pending);
    s->regs[R_GICP_PMC_IRQ_STATUS] |= pending << 5;
    gicp_pmc_irq_update_irq(s);
}

static void gicp5_irq_status_postw(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    gicp5_irq_update_irq(s);
}

static uint64_t gicp5_irq_enable_prew(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    uint32_t val = val64;

    s->regs[R_GICP5_IRQ_MASK] &= ~val;
    gicp5_irq_update_irq(s);
    return 0;
}

static uint64_t gicp5_irq_disable_prew(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    uint32_t val = val64;

    s->regs[R_GICP5_IRQ_MASK] |= val;
    gicp5_irq_update_irq(s);
    return 0;
}

static uint64_t gicp5_irq_trigger_prew(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    uint32_t val = val64;

    s->regs[R_GICP5_IRQ_STATUS] |= val;
    gicp5_irq_update_irq(s);
    return 0;
}

static void gicp6_irq_update_irq(PMCGICProxy *s)
{
    bool pending = s->regs[R_GICP6_IRQ_STATUS] & ~s->regs[R_GICP6_IRQ_MASK];
    qemu_set_irq(s->irq_gicp6_irq, pending);
    s->regs[R_GICP_PMC_IRQ_STATUS] |= pending << 6;
    gicp_pmc_irq_update_irq(s);
}

static void gicp6_irq_status_postw(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    gicp6_irq_update_irq(s);
}

static uint64_t gicp6_irq_enable_prew(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    uint32_t val = val64;

    s->regs[R_GICP6_IRQ_MASK] &= ~val;
    gicp6_irq_update_irq(s);
    return 0;
}

static uint64_t gicp6_irq_disable_prew(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    uint32_t val = val64;

    s->regs[R_GICP6_IRQ_MASK] |= val;
    gicp6_irq_update_irq(s);
    return 0;
}

static uint64_t gicp6_irq_trigger_prew(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    uint32_t val = val64;

    s->regs[R_GICP6_IRQ_STATUS] |= val;
    gicp6_irq_update_irq(s);
    return 0;
}

static void gicp7_irq_update_irq(PMCGICProxy *s)
{
    bool pending = s->regs[R_GICP7_IRQ_STATUS] & ~s->regs[R_GICP7_IRQ_MASK];
    qemu_set_irq(s->irq_gicp7_irq, pending);
    s->regs[R_GICP_PMC_IRQ_STATUS] |= pending << 7;
    gicp_pmc_irq_update_irq(s);
}

static void gicp7_irq_status_postw(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    gicp7_irq_update_irq(s);
}

static uint64_t gicp7_irq_enable_prew(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    uint32_t val = val64;

    s->regs[R_GICP7_IRQ_MASK] &= ~val;
    gicp7_irq_update_irq(s);
    return 0;
}

static uint64_t gicp7_irq_disable_prew(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    uint32_t val = val64;

    s->regs[R_GICP7_IRQ_MASK] |= val;
    gicp7_irq_update_irq(s);
    return 0;
}

static uint64_t gicp7_irq_trigger_prew(DepRegisterInfo *reg, uint64_t val64)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(reg->opaque);
    uint32_t val = val64;

    s->regs[R_GICP7_IRQ_STATUS] |= val;
    gicp7_irq_update_irq(s);
    return 0;
}

static DepRegisterAccessInfo pmc_gic_proxy_regs_info[] = {
    {   .name = "GICP0_IRQ_STATUS",  .decode.addr = A_GICP0_IRQ_STATUS,
        .w1c = 0xffffffff,
        .post_write = gicp0_irq_status_postw,
    },{ .name = "GICP0_IRQ_MASK",  .decode.addr = A_GICP0_IRQ_MASK,
        .reset = 0xffffffff,
        .ro = 0xffffffff,
    },{ .name = "GICP0_IRQ_ENABLE",  .decode.addr = A_GICP0_IRQ_ENABLE,
        .pre_write = gicp0_irq_enable_prew,
    },{ .name = "GICP0_IRQ_DISABLE",  .decode.addr = A_GICP0_IRQ_DISABLE,
        .pre_write = gicp0_irq_disable_prew,
    },{ .name = "GICP0_IRQ_TRIGGER",  .decode.addr = A_GICP0_IRQ_TRIGGER,
        .pre_write = gicp0_irq_trigger_prew,
    },{ .name = "GICP1_IRQ_STATUS",  .decode.addr = A_GICP1_IRQ_STATUS,
        .w1c = 0xffffffff,
        .post_write = gicp1_irq_status_postw,
    },{ .name = "GICP1_IRQ_MASK",  .decode.addr = A_GICP1_IRQ_MASK,
        .reset = 0xffffffff,
        .ro = 0xffffffff,
    },{ .name = "GICP1_IRQ_ENABLE",  .decode.addr = A_GICP1_IRQ_ENABLE,
        .pre_write = gicp1_irq_enable_prew,
    },{ .name = "GICP1_IRQ_DISABLE",  .decode.addr = A_GICP1_IRQ_DISABLE,
        .pre_write = gicp1_irq_disable_prew,
    },{ .name = "GICP1_IRQ_TRIGGER",  .decode.addr = A_GICP1_IRQ_TRIGGER,
        .pre_write = gicp1_irq_trigger_prew,
    },{ .name = "GICP2_IRQ_STATUS",  .decode.addr = A_GICP2_IRQ_STATUS,
        .w1c = 0xffffffff,
        .post_write = gicp2_irq_status_postw,
    },{ .name = "GICP2_IRQ_MASK",  .decode.addr = A_GICP2_IRQ_MASK,
        .reset = 0xffffffff,
        .ro = 0xffffffff,
    },{ .name = "GICP2_IRQ_ENABLE",  .decode.addr = A_GICP2_IRQ_ENABLE,
        .pre_write = gicp2_irq_enable_prew,
    },{ .name = "GICP2_IRQ_DISABLE",  .decode.addr = A_GICP2_IRQ_DISABLE,
        .pre_write = gicp2_irq_disable_prew,
    },{ .name = "GICP2_IRQ_TRIGGER",  .decode.addr = A_GICP2_IRQ_TRIGGER,
        .pre_write = gicp2_irq_trigger_prew,
    },{ .name = "GICP3_IRQ_STATUS",  .decode.addr = A_GICP3_IRQ_STATUS,
        .w1c = 0xffffffff,
        .post_write = gicp3_irq_status_postw,
    },{ .name = "GICP3_IRQ_MASK",  .decode.addr = A_GICP3_IRQ_MASK,
        .reset = 0xffffffff,
        .ro = 0xffffffff,
    },{ .name = "GICP3_IRQ_ENABLE",  .decode.addr = A_GICP3_IRQ_ENABLE,
        .pre_write = gicp3_irq_enable_prew,
    },{ .name = "GICP3_IRQ_DISABLE",  .decode.addr = A_GICP3_IRQ_DISABLE,
        .pre_write = gicp3_irq_disable_prew,
    },{ .name = "GICP3_IRQ_TRIGGER",  .decode.addr = A_GICP3_IRQ_TRIGGER,
        .pre_write = gicp3_irq_trigger_prew,
    },{ .name = "GICP4_IRQ_STATUS",  .decode.addr = A_GICP4_IRQ_STATUS,
        .w1c = 0xffffffff,
        .post_write = gicp4_irq_status_postw,
    },{ .name = "GICP4_IRQ_MASK",  .decode.addr = A_GICP4_IRQ_MASK,
        .reset = 0xffffffff,
        .ro = 0xffffffff,
    },{ .name = "GICP4_IRQ_ENABLE",  .decode.addr = A_GICP4_IRQ_ENABLE,
        .pre_write = gicp4_irq_enable_prew,
    },{ .name = "GICP4_IRQ_DISABLE",  .decode.addr = A_GICP4_IRQ_DISABLE,
        .pre_write = gicp4_irq_disable_prew,
    },{ .name = "GICP4_IRQ_TRIGGER",  .decode.addr = A_GICP4_IRQ_TRIGGER,
        .pre_write = gicp4_irq_trigger_prew,
    },{ .name = "GICP5_IRQ_STATUS",  .decode.addr = A_GICP5_IRQ_STATUS,
        .w1c = 0xffffffff,
        .post_write = gicp5_irq_status_postw,
    },{ .name = "GICP5_IRQ_MASK",  .decode.addr = A_GICP5_IRQ_MASK,
        .reset = 0xffffffff,
        .ro = 0xffffffff,
    },{ .name = "GICP5_IRQ_ENABLE",  .decode.addr = A_GICP5_IRQ_ENABLE,
        .pre_write = gicp5_irq_enable_prew,
    },{ .name = "GICP5_IRQ_DISABLE",  .decode.addr = A_GICP5_IRQ_DISABLE,
        .pre_write = gicp5_irq_disable_prew,
    },{ .name = "GICP5_IRQ_TRIGGER",  .decode.addr = A_GICP5_IRQ_TRIGGER,
        .pre_write = gicp5_irq_trigger_prew,
    },{ .name = "GICP6_IRQ_STATUS",  .decode.addr = A_GICP6_IRQ_STATUS,
        .w1c = 0xffffffff,
        .post_write = gicp6_irq_status_postw,
    },{ .name = "GICP6_IRQ_MASK",  .decode.addr = A_GICP6_IRQ_MASK,
        .reset = 0xffffffff,
        .ro = 0xffffffff,
    },{ .name = "GICP6_IRQ_ENABLE",  .decode.addr = A_GICP6_IRQ_ENABLE,
        .pre_write = gicp6_irq_enable_prew,
    },{ .name = "GICP6_IRQ_DISABLE",  .decode.addr = A_GICP6_IRQ_DISABLE,
        .pre_write = gicp6_irq_disable_prew,
    },{ .name = "GICP6_IRQ_TRIGGER",  .decode.addr = A_GICP6_IRQ_TRIGGER,
        .pre_write = gicp6_irq_trigger_prew,
    },{ .name = "GICP7_IRQ_STATUS",  .decode.addr = A_GICP7_IRQ_STATUS,
        .w1c = 0xffffffff,
        .post_write = gicp7_irq_status_postw,
    },{ .name = "GICP7_IRQ_MASK",  .decode.addr = A_GICP7_IRQ_MASK,
        .reset = 0xffffffff,
        .ro = 0xffffffff,
    },{ .name = "GICP7_IRQ_ENABLE",  .decode.addr = A_GICP7_IRQ_ENABLE,
        .pre_write = gicp7_irq_enable_prew,
    },{ .name = "GICP7_IRQ_DISABLE",  .decode.addr = A_GICP7_IRQ_DISABLE,
        .pre_write = gicp7_irq_disable_prew,
    },{ .name = "GICP7_IRQ_TRIGGER",  .decode.addr = A_GICP7_IRQ_TRIGGER,
        .pre_write = gicp7_irq_trigger_prew,
    },{ .name = "GICP_PMC_IRQ_STATUS",  .decode.addr = A_GICP_PMC_IRQ_STATUS,
        .rsvd = 0xffffff00,
        .w1c = 0xff,
        .post_write = gicp_pmc_irq_status_postw,
    },{ .name = "GICP_PMC_IRQ_MASK",  .decode.addr = A_GICP_PMC_IRQ_MASK,
        .reset = 0xff,
        .rsvd = 0xffffff00,
        .ro = 0xff,
    },{ .name = "GICP_PMC_IRQ_ENABLE",  .decode.addr = A_GICP_PMC_IRQ_ENABLE,
        .rsvd = 0xffffff00,
        .pre_write = gicp_pmc_irq_enable_prew,
    },{ .name = "GICP_PMC_IRQ_DISABLE",  .decode.addr = A_GICP_PMC_IRQ_DISABLE,
        .rsvd = 0xffffff00,
        .pre_write = gicp_pmc_irq_disable_prew,
    },{ .name = "GICP_PMC_IRQ_TRIGGER",  .decode.addr = A_GICP_PMC_IRQ_TRIGGER,
        .rsvd = 0xffffff00,
        .pre_write = gicp_pmc_irq_trigger_prew,
    }
};

static void pmc_gic_proxy_reset(DeviceState *dev)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(dev);
    unsigned int i;

    for (i = 0; i < ARRAY_SIZE(s->regs_info); ++i) {
        dep_register_reset(&s->regs_info[i]);
    }

    gicp0_irq_update_irq(s);
    gicp1_irq_update_irq(s);
    gicp2_irq_update_irq(s);
    gicp3_irq_update_irq(s);
    gicp4_irq_update_irq(s);
    gicp5_irq_update_irq(s);
    gicp6_irq_update_irq(s);
    gicp7_irq_update_irq(s);
    gicp_pmc_irq_update_irq(s);
}

static uint64_t pmc_gic_proxy_read(void *opaque, hwaddr addr, unsigned size)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(opaque);
    DepRegisterInfo *r = &s->regs_info[addr / 4];

    if (!r->data) {
        qemu_log("%s: Decode error: read from %" HWADDR_PRIx "\n",
                 object_get_canonical_path(OBJECT(s)),
                 addr);
        return 0;
    }
    return dep_register_read(r);
}

static void pmc_gic_proxy_write(void *opaque, hwaddr addr, uint64_t value,
                      unsigned size)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(opaque);
    DepRegisterInfo *r = &s->regs_info[addr / 4];

    if (!r->data) {
        qemu_log("%s: Decode error: write to %" HWADDR_PRIx "=%" PRIx64 "\n",
                 object_get_canonical_path(OBJECT(s)),
                 addr, value);
        return;
    }
    dep_register_write(r, value, ~0);
}

static const MemoryRegionOps pmc_gic_proxy_ops = {
    .read = pmc_gic_proxy_read,
    .write = pmc_gic_proxy_write,
    .endianness = DEVICE_LITTLE_ENDIAN,
    .valid = {
        .min_access_size = 4,
        .max_access_size = 4,
    },
};

static void pmc_gic_proxy_realize(DeviceState *dev, Error **errp)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(dev);
    const char *prefix = object_get_canonical_path(OBJECT(dev));
    unsigned int i;

    for (i = 0; i < ARRAY_SIZE(pmc_gic_proxy_regs_info); ++i) {
        DepRegisterInfo *r;

        r = &s->regs_info[pmc_gic_proxy_regs_info[i].decode.addr / 4];
        *r = (DepRegisterInfo) {
            .data = (uint8_t *)&s->regs[
                    pmc_gic_proxy_regs_info[i].decode.addr / 4],
            .data_size = sizeof(uint32_t),
            .access = &pmc_gic_proxy_regs_info[i],
            .debug = XILINX_PMC_GIC_PROXY_ERR_DEBUG,
            .prefix = prefix,
            .opaque = s,
        };
    }
}

static void pmc_gic_proxy_init(Object *obj)
{
    PMCGICProxy *s = XILINX_PMC_GIC_PROXY(obj);
    SysBusDevice *sbd = SYS_BUS_DEVICE(obj);

    memory_region_init_io(&s->iomem, obj, &pmc_gic_proxy_ops, s,
                          TYPE_XILINX_PMC_GIC_PROXY, R_MAX * 4);
    sysbus_init_mmio(sbd, &s->iomem);

    sysbus_init_irq(sbd, &s->irq_gicp_pmc_irq);
    sysbus_init_irq(sbd, &s->irq_gicp0_irq);
    sysbus_init_irq(sbd, &s->irq_gicp1_irq);
    sysbus_init_irq(sbd, &s->irq_gicp2_irq);
    sysbus_init_irq(sbd, &s->irq_gicp3_irq);
    sysbus_init_irq(sbd, &s->irq_gicp4_irq);
    sysbus_init_irq(sbd, &s->irq_gicp5_irq);
    sysbus_init_irq(sbd, &s->irq_gicp6_irq);
    sysbus_init_irq(sbd, &s->irq_gicp7_irq);
}

static const VMStateDescription vmstate_pmc_gic_proxy = {
    .name = TYPE_XILINX_PMC_GIC_PROXY,
    .version_id = 1,
    .minimum_version_id = 1,
    .minimum_version_id_old = 1,
    .fields = (VMStateField[]) {
        VMSTATE_UINT32_ARRAY(regs, PMCGICProxy, R_MAX),
        VMSTATE_END_OF_LIST(),
    }
};

static void pmc_gic_proxy_class_init(ObjectClass *klass, void *data)
{
    DeviceClass *dc = DEVICE_CLASS(klass);

    dc->reset = pmc_gic_proxy_reset;
    dc->realize = pmc_gic_proxy_realize;
    dc->vmsd = &vmstate_pmc_gic_proxy;
}

static const TypeInfo pmc_gic_proxy_info = {
    .name          = TYPE_XILINX_PMC_GIC_PROXY,
    .parent        = TYPE_SYS_BUS_DEVICE,
    .instance_size = sizeof(PMCGICProxy),
    .class_init    = pmc_gic_proxy_class_init,
    .instance_init = pmc_gic_proxy_init,
};

static void pmc_gic_proxy_register_types(void)
{
    type_register_static(&pmc_gic_proxy_info);
}

type_init(pmc_gic_proxy_register_types)
